@@ -35,6 +35,7 @@
 
 #include <cpl.h>
 #include <string.h>
+#include <strings.h>
 
 #include "casu_mods.h"
 #include "casu_stats.h"
@@ -358,14 +359,21 @@ extern int casu_matchstds(cpl_table *objtab, cpl_table *stdstab, float srad,
 
     /* Calculate the error limit and the number of grid points */
 
+    // This is the average density of stars in the image
+    // FIXME it is incorrect to assume NX and NY are fixed
     aveden = (float)max(nstd,nobj)/(float)(NX*NY);
+    // An initial estimate of a sensible error limit
     errlim = 1.0/sqrt(4.0*CPL_MATH_PI*aveden);
     errlim = min(errlim,15.0);
+    // The grid size to achieve this
     ngrid = (int)(srad/errlim);
     ngrid = (ngrid/2)*2 + 1;
+    // Constrain the number of grid points
     ngrid = max(5,min(NGRIDMAX_STD,ngrid));
     ngrid2 = ngrid/2 + 1;
 
+    cpl_msg_info(fctid, "Search radius is %f pixels. Using a %d x %d grid, with error limit of %f", srad, ngrid, ngrid, errlim);
+
     /* Now search for the best solution */
 
     ibest = 0;
@@ -450,6 +458,8 @@ extern int casu_matchstds(cpl_table *objtab, cpl_table *stdstab, float srad,
         sigy *= 1.48;
     }
 
+    cpl_msg_info(fctid, "Median offset x=%f y=%f, sigx=%f sigy=%f", xoffmed, yoffmed, sigx, sigy);
+
     /* Now go through one final time with a reduced error box and get
        the final matches */
 
@@ -492,7 +502,7 @@ extern int casu_matchstds(cpl_table *objtab, cpl_table *stdstab, float srad,
     ig = (int)cpl_array_get_size(colnames);
     for (k = 0; k < ig; k++) {
         colname = (char *)cpl_array_get_string(colnames,(cpl_size)k);
-        if (strcmp(colname,"RA") && strcmp(colname,"DEC"))
+        if (strcasecmp(colname,"RA") && strcasecmp(colname,"DEC"))
             cpl_table_new_column(mstds,colname,
                                  cpl_table_get_column_type(objtab,colname));
     }
@@ -512,7 +522,7 @@ extern int casu_matchstds(cpl_table *objtab, cpl_table *stdstab, float srad,
             for (k2 = 0; k2 < ig; k2++) {
                 colname = (char *)cpl_array_get_string(colnames,
                                                              (cpl_size)k2);
-                if (!strcmp(colname,"RA") || !strcmp(colname,"DEC")) 
+                if (!strcasecmp(colname,"RA") || !strcasecmp(colname,"DEC")) 
                     continue;
                 null = 0;
                 switch (cpl_table_get_column_type(objtab,colname)) {
@@ -531,10 +541,13 @@ extern int casu_matchstds(cpl_table *objtab, cpl_table *stdstab, float srad,
                                          cpl_table_get_double(objtab,colname,
                                                               (cpl_size)jm,&null));
                     break;
+                case CPL_TYPE_STRING:
+                    cpl_table_set_string(mstds,colname,(cpl_size)k,
+                                         cpl_table_get_string(objtab,colname,
+                                                              (cpl_size)jm));
+                    break;
                 default:
-                    cpl_table_set_float(mstds,colname,(cpl_size)k,
-                                        cpl_table_get_float(objtab,colname,
-                                                            (cpl_size)jm,&null));
+                    cpl_msg_info(fctid, "Ignoring column %s of type %d", colname, cpl_table_get_column_type(objtab,colname));
                     break;
                 }
             }
