@@ -56,6 +56,7 @@ extern int casu_getstds(cpl_propertylist *plist, int cache, char *path,
                         cpl_table **stds, int *status);
 extern int casu_getstds_cdslist(int cdschoice, char **cdscatname,
                                 char **cdscatid, int *status);
+extern int casu_get_cdschoice(const char* cdscatname);
 extern int casu_imcombine(casu_fits **fset, casu_fits **fsetv, int nfits, 
                           int combtype, int scaletype, int xrej, float thresh, 
                           const char *expkey, cpl_image **outimage, 
@@ -78,7 +79,7 @@ extern int casu_imstack(casu_fits **inf, casu_fits **inconf, casu_fits **invar,
 extern int casu_inpaint(casu_fits *in, int nbsize, int *status);
 extern int casu_matchstds(cpl_table *objtab, cpl_table *stdstab, float srad,
                           cpl_table **outtab, int *status);
-extern int casu_matchxy(cpl_table *progtab, cpl_table *template, float srad,
+extern int casu_matchxy(cpl_table *progtab, cpl_table *tmplate, float srad,
                         float *xoffset, float *yoffset, int *nm, 
                         cpl_table **outtab, int *status);
 extern int casu_mkconf(cpl_image *flat, char *flatfile, casu_mask *bpm, 
