@@ -512,11 +512,7 @@ char *pilFileTrimPath(char *path)
 
   char tpath[PIL_PATHNAME_MAX + 1];
 
-#define HAVE_WORDEXP 1
-#ifdef HAVE_WORDEXP
   wordexp_t pwordexp = {0, 0, 0};
-#endif
-
 
 
   /*
@@ -525,10 +521,6 @@ char *pilFileTrimPath(char *path)
 
   *expanded_path = '\0';
 
-#ifndef HAVE_WORDEXP
-#error No replacement for wordexp() is currently implemented!
-#else
-
   /*
    * Perform tilde, variable expansion. The expanded path must
    * be unique.
@@ -550,8 +542,6 @@ char *pilFileTrimPath(char *path)
     wordfree(&pwordexp);
   }
     
-#endif
-
   /*
    * Convert the path string into an absolute path resolving the
    * special tokens '.' and '..'.
