@@ -34,7 +34,7 @@
 #include "pillist.h"
 
 
-inline PilListNode *pilListExtract(PilList *, PilListNode *);
+ PilListNode *pilListExtract(PilList *, PilListNode *);
 
 
 /**
@@ -66,7 +66,7 @@ inline PilListNode *pilListExtract(PilList *, PilListNode *);
  * pointer @em data.
  */
 
-inline PilListNode *newPilListNode(void *data)
+ PilListNode *newPilListNode(void *data)
 {
 
     return lnode_create(data);
@@ -86,7 +86,7 @@ inline PilListNode *newPilListNode(void *data)
  * pointed to by @em node is nopt deallocated by the destructor!
  */
 
-inline void deletePilListNode(PilListNode *node)
+ void deletePilListNode(PilListNode *node)
 {
 
     if (node)
@@ -111,7 +111,7 @@ inline void deletePilListNode(PilListNode *node)
  * @see pilListNodePut()
  */
 
-inline void *pilListNodeGet(const PilListNode *node)
+ void *pilListNodeGet(const PilListNode *node)
 {
 
     return lnode_get(node);
@@ -133,7 +133,7 @@ inline void *pilListNodeGet(const PilListNode *node)
  * @see pilListNodeGet()
  */
 
-inline void pilListNodePut(PilListNode *node, const void *data)
+ void pilListNodePut(PilListNode *node, const void *data)
 {
 
     lnode_put(node, (void *)data);
@@ -155,7 +155,7 @@ inline void pilListNodePut(PilListNode *node, const void *data)
  * by checking whether the node has a predecessor or a successor.
  */
 
-inline int pilListNodeIsListMember(const PilListNode *node)
+ int pilListNodeIsListMember(const PilListNode *node)
 {
 
     return lnode_is_in_a_list((PilListNode *)node);
@@ -177,7 +177,7 @@ inline int pilListNodeIsListMember(const PilListNode *node)
  * @see pilListEnd()
  */
 
-inline PilListNode *pilListBegin(const PilList *list)
+ PilListNode *pilListBegin(const PilList *list)
 {
 
     return list_first(list);
@@ -199,7 +199,7 @@ inline PilListNode *pilListBegin(const PilList *list)
  * @see pilListBegin()
  */
 
-inline PilListNode *pilListEnd(const PilList *list)
+ PilListNode *pilListEnd(const PilList *list)
 {
 
     return list_last(list);
@@ -223,7 +223,7 @@ inline PilListNode *pilListEnd(const PilList *list)
  * @see pilListPrev()
  */
 
-inline PilListNode *pilListNext(const PilList *list, const PilListNode *node)
+ PilListNode *pilListNext(const PilList *list, const PilListNode *node)
 {
 
     return list_next(list, node);
@@ -247,7 +247,7 @@ inline PilListNode *pilListNext(const PilList *list, const PilListNode *node)
  * @see pilListNext()
  */
 
-inline PilListNode *pilListPrev(const PilList *list, const PilListNode *node)
+ PilListNode *pilListPrev(const PilList *list, const PilListNode *node)
 {
 
     return list_prev(list, node);
@@ -273,7 +273,7 @@ inline PilListNode *pilListPrev(const PilList *list, const PilListNode *node)
  * @see pilListErase(), pilListExtract(), pilListPopFront(), pilListPopBack()
  */
 
-inline void pilListClear(PilList *list)
+ void pilListClear(PilList *list)
 {
 
     if (list)
@@ -298,7 +298,7 @@ inline void pilListClear(PilList *list)
  * @see pilListIsFull()
  */
 
-inline int pilListIsEmpty(const PilList *list)
+ int pilListIsEmpty(const PilList *list)
 {
 
     return list_isempty((PilList *)list);
@@ -317,7 +317,7 @@ inline int pilListIsEmpty(const PilList *list)
  * to an empty list.
  */
 
-inline PilList *newPilList(void)
+ PilList *newPilList(void)
 {
 
     return list_create(LISTCOUNT_T_MAX);
@@ -339,7 +339,7 @@ inline PilList *newPilList(void)
  * @see pilListClear(), pilListDestroy()
  */
 
-inline void deletePilList(PilList *list)
+ void deletePilList(PilList *list)
 {
 
     if (list)
@@ -366,7 +366,7 @@ inline void deletePilList(PilList *list)
  * @see pilListClear(), deletePilList()
  */
 
-inline void pilListDestroy(PilList *list, void (*deallocate)(void *))
+ void pilListDestroy(PilList *list, void (*deallocate)(void *))
 {
 
     PilListNode *node;
@@ -412,7 +412,7 @@ inline void pilListDestroy(PilList *list, void (*deallocate)(void *))
  * the list @em list.
  */
 
-inline PilListSize pilListSize(const PilList *list)
+ PilListSize pilListSize(const PilList *list)
 {
 
     return list_count(list);
@@ -432,7 +432,7 @@ inline PilListSize pilListSize(const PilList *list)
  * the list @em list.
  */
 
-inline PilListSize pilListMaxSize(const PilList *list)
+ PilListSize pilListMaxSize(const PilList *list)
 {
 
     assert(list != NULL);
@@ -456,7 +456,7 @@ inline PilListSize pilListMaxSize(const PilList *list)
  * @see pilListIsEmpty()
  */
 
-inline int pilListIsFull(const PilList *list)
+ int pilListIsFull(const PilList *list)
 {
 
     return list_isfull((PilList *)list);
@@ -480,7 +480,7 @@ inline int pilListIsFull(const PilList *list)
  * @see pilListNodeIsMember()
  */
 
-inline int pilListContains(const PilList *list, const PilListNode *node)
+ int pilListContains(const PilList *list, const PilListNode *node)
 {
 
     return list_contains((PilList *)list, (PilListNode *)node);
@@ -501,7 +501,7 @@ inline int pilListContains(const PilList *list, const PilListNode *node)
  * debugging purposes only and should be placed in assert statements.
  */
 
-inline int pilListVerify(const PilList *list)
+ int pilListVerify(const PilList *list)
 {
 
     return list_verify((PilList *)list);
@@ -523,7 +523,7 @@ inline int pilListVerify(const PilList *list)
  * @em position into the list @em list.
  */
 
-inline PilListNode *pilListInsert(PilList *list, PilListNode *position,
+ PilListNode *pilListInsert(PilList *list, PilListNode *position,
                                   PilListNode *node)
 {
 
@@ -547,7 +547,7 @@ inline PilListNode *pilListInsert(PilList *list, PilListNode *position,
  * @em position into the list @em list.
  */
 
-inline PilListNode *pilListInsertAfter(PilList *list, PilListNode *position,
+ PilListNode *pilListInsertAfter(PilList *list, PilListNode *position,
                                        PilListNode *node)
 {
 
@@ -569,7 +569,7 @@ inline PilListNode *pilListInsertAfter(PilList *list, PilListNode *position,
  * The function prepends the node @em node to the list @em list. 
  */
 
-inline void pilListPushFront(PilList *list, PilListNode *node)
+ void pilListPushFront(PilList *list, PilListNode *node)
 {
 
     list_prepend(list, node);
@@ -590,7 +590,7 @@ inline void pilListPushFront(PilList *list, PilListNode *node)
  * The function appends the node @em node to the list @em list.
  */
 
-inline void pilListPushBack(PilList *list, PilListNode *node)
+ void pilListPushBack(PilList *list, PilListNode *node)
 {
 
     list_append(list, node);
@@ -616,7 +616,7 @@ inline void pilListPushBack(PilList *list, PilListNode *node)
  * @see pilListClear(), pilListExtract(), pilListPopFront(), pilListPopBack()
  */
 
-inline void pilListErase(PilList *list, PilListNode *node,
+ void pilListErase(PilList *list, PilListNode *node,
                          void (*deallocate)(void *))
 {
 
@@ -654,7 +654,7 @@ inline void pilListErase(PilList *list, PilListNode *node,
  * @see pilListErase(), pilListClear(), pilListPopFront(), pilListPopBack()
  */
 
-inline PilListNode *pilListExtract(PilList *list, PilListNode *node)
+ PilListNode *pilListExtract(PilList *list, PilListNode *node)
 {
 
     return list_delete(list, node);
@@ -675,7 +675,7 @@ inline PilListNode *pilListExtract(PilList *list, PilListNode *node)
  * @see pilListPopBack(), pilListExtract(), pilListErase(), pilListClear()
  */
 
-inline PilListNode *pilListPopFront(PilList *list)
+ PilListNode *pilListPopFront(PilList *list)
 {
 
     return list_del_first(list);
@@ -696,7 +696,7 @@ inline PilListNode *pilListPopFront(PilList *list)
  * @see pilListPopFront(), pilListExtract(), pilListErase(), pilListClear()
  */
 
-inline PilListNode *pilListPopBack(PilList *list)
+ PilListNode *pilListPopBack(PilList *list)
 {
 
     return list_del_last(list);
@@ -721,7 +721,7 @@ inline PilListNode *pilListPopBack(PilList *list)
  * the destination list @em dst.
  */
 
-inline void pilListTransfer(PilList *dst, PilList *src, PilListNode *begin,
+ void pilListTransfer(PilList *dst, PilList *src, PilListNode *begin,
                             PilListNode *end)
 {
 
@@ -754,7 +754,7 @@ inline void pilListTransfer(PilList *dst, PilList *src, PilListNode *begin,
  * @see pilListSplice()
  */
 
-inline void pilListMerge(PilList *dst, PilList *src, 
+ void pilListMerge(PilList *dst, PilList *src, 
 			 int (*compare)(const void *, const void *))
 {
 
@@ -784,7 +784,7 @@ inline void pilListMerge(PilList *dst, PilList *src,
  * @see pilListTransfer(), pilListMerge()
  */
 
-inline void pilListSplice(PilList *dst, PilListNode *pos, PilList *src,
+ void pilListSplice(PilList *dst, PilListNode *pos, PilList *src,
 			  PilListNode *begin, PilListNode *end)
 {
 
@@ -822,7 +822,7 @@ inline void pilListSplice(PilList *dst, PilListNode *pos, PilList *src,
  * @see pilListIsSorted()
  */
 
-inline void pilListSort(PilList *list,
+ void pilListSort(PilList *list,
                         int (*compare)(const void *, const void *))
 {
 
@@ -849,7 +849,7 @@ inline void pilListSort(PilList *list,
  * @see pilListSort()
  */
 
-inline int pilListIsSorted(PilList *list,
+ int pilListIsSorted(PilList *list,
 			   int (*compare)(const void *, const void *))
 {
 
@@ -880,7 +880,7 @@ inline int pilListIsSorted(PilList *list,
  * in the list, the comparison function returns 0.
  */
 
-inline PilListNode *pilListLookup(PilList *list, const void *key,
+ PilListNode *pilListLookup(PilList *list, const void *key,
 				  int (*compare)(const void *, const void *))
 {
 
