@@ -1578,12 +1578,12 @@ pilRecStart(const char *instrument, const char *recipe, const char *version,
     switch (c) {
     case 'h':
       pilRecUsage(parg);
-      exit(0);
+      return NULL;
       break;
 
     case 'V':
       pilRecVersion();
-      exit(0);
+      return NULL;
       break;
 
     case 'D':
@@ -1852,7 +1852,7 @@ pilRecStart(const char *instrument, const char *recipe, const char *version,
     if (dump_file)
       pil_free(dump_file);
 
-    exit(status);
+    return NULL;
   }
 
 
