@@ -30,7 +30,6 @@
 #include "hdrl_sigclip.h"
 #include "hdrl_utils.h"
 #include "hdrl_collapse.h"
-#include <assert.h>
 
 #include <cpl.h>
 #include <math.h>
@@ -58,6 +57,11 @@ static void hdrl_overscan_parameter_destroy(void * param);
 /**
   @defgroup hdrl_overscan   Overscan Computation and Correction
  
+  @brief
+  This module contains functionality to compute and correct the overscan level
+  of CCD image.
+
+
 The overscan (or prescan) region on a CCD can consist of physical
 pixels on the detector that are not illuminated, or it can consist of a set
 of virtual pixels created by reading out the serial register either before or
@@ -175,7 +179,7 @@ cpl_error_code hdrl_overscan_parameter_verify(
         cpl_size                    ny) 
 {
     const hdrl_overscan_parameter * param_loc = 
-        (hdrl_overscan_parameter *)param ;
+        (const hdrl_overscan_parameter *)param ;
 
     cpl_error_ensure(param != NULL, CPL_ERROR_NULL_INPUT,
             return CPL_ERROR_NULL_INPUT, "NULL Input Parameters");
@@ -210,6 +214,13 @@ cpl_error_code hdrl_overscan_parameter_verify(
                 return CPL_ERROR_ILLEGAL_INPUT,
                 "Illegal Collapse Minmax parameters");
     } 
+    if (hdrl_collapse_parameter_is_mode(param_loc->collapse)) {
+        cpl_error_ensure(
+                hdrl_collapse_mode_parameter_verify(param_loc->collapse)
+                == CPL_ERROR_NONE, CPL_ERROR_ILLEGAL_INPUT,
+                return CPL_ERROR_ILLEGAL_INPUT,
+                "Illegal Collapse Mode parameters");
+    } 
     cpl_error_ensure(
             hdrl_rect_region_parameter_verify(param_loc->rect_region, -1, -1)
             == CPL_ERROR_NONE, CPL_ERROR_ILLEGAL_INPUT,
@@ -220,10 +231,11 @@ cpl_error_code hdrl_overscan_parameter_verify(
             hdrl_collapse_parameter_is_weighted_mean(param_loc->collapse) ||
             hdrl_collapse_parameter_is_median(param_loc->collapse) ||
             hdrl_collapse_parameter_is_sigclip(param_loc->collapse) ||
-            hdrl_collapse_parameter_is_minmax(param_loc->collapse),
+            hdrl_collapse_parameter_is_minmax(param_loc->collapse) ||
+            hdrl_collapse_parameter_is_mode(param_loc->collapse),
             CPL_ERROR_ILLEGAL_INPUT, return CPL_ERROR_ILLEGAL_INPUT,
             "Only supported methods are MEAN, WEIGHTED_MEAN, MEDIAN, SIGCLIP,"
-            " and MINMAX");
+            " MINMAX and MODE");
 
     /* The region must be contained in the image */
     if (nx > 0) {
@@ -270,7 +282,7 @@ hdrl_direction hdrl_overscan_parameter_get_correction_direction(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, HDRL_UNDEFINED_AXIS);
-    return ((hdrl_overscan_parameter *)p)->correction_direction;
+    return ((const hdrl_overscan_parameter *)p)->correction_direction;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -283,7 +295,7 @@ double hdrl_overscan_parameter_get_ccd_ron(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, -1.0) ;
-    return ((hdrl_overscan_parameter *)p)->ccd_ron ;
+    return ((const hdrl_overscan_parameter *)p)->ccd_ron ;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -296,7 +308,7 @@ int hdrl_overscan_parameter_get_box_hsize(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, -1.0) ;
-    return ((hdrl_overscan_parameter *)p)->box_hsize ;
+    return ((const hdrl_overscan_parameter *)p)->box_hsize ;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -309,7 +321,7 @@ hdrl_parameter * hdrl_overscan_parameter_get_collapse(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, NULL) ;
-    return ((hdrl_overscan_parameter *)p)->collapse;
+    return ((const hdrl_overscan_parameter *)p)->collapse;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -322,7 +334,7 @@ hdrl_parameter * hdrl_overscan_parameter_get_rect_region(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, NULL) ;
-    return ((hdrl_overscan_parameter *)p)->rect_region;
+    return ((const hdrl_overscan_parameter *)p)->rect_region;
 }
 
 /* ---------------------------------------------------------------------------*/
@@ -337,6 +349,7 @@ hdrl_parameter * hdrl_overscan_parameter_get_rect_region(
   @param method_def      default collapse method value
   @param sigclip_def     default sigma-clipping parameters 
   @param minmax_def      default minmax-clipping parameters 
+  @param mode_def      default mode-clipping parameters 
 
   @see hdrl_rect_region_parameter_create_parlist()
   @see hdrl_collapse_parameter_create_parlist()
@@ -352,17 +365,26 @@ hdrl_parameter * hdrl_overscan_parameter_get_rect_region(
  */
 /* ---------------------------------------------------------------------------*/
 cpl_parameterlist * hdrl_overscan_parameter_create_parlist(
-        const char      *   base_context,
-        const char      *   prefix,
-        const char      *   corr_dir_def,
-        int                 box_hsize_def,
-        double              ccd_ron_def,
-        hdrl_parameter  *   rect_region_def,
-        const char      *   method_def,
-        hdrl_parameter  *   sigclip_def,
-        hdrl_parameter  *   minmax_def)
+        const char      *base_context,
+        const char      *prefix,
+        const char      *corr_dir_def,
+        int              box_hsize_def,
+        double           ccd_ron_def,
+        hdrl_parameter  *rect_region_def,
+        const char      *method_def,
+        hdrl_parameter  *sigclip_def,
+        hdrl_parameter  *minmax_def,
+	hdrl_parameter  *mode_def)
 {
-    cpl_ensure(prefix && base_context, CPL_ERROR_NULL_INPUT, NULL);
+    cpl_ensure(prefix && base_context && rect_region_def && sigclip_def
+	       && minmax_def && mode_def, CPL_ERROR_NULL_INPUT, NULL);
+
+    cpl_ensure(hdrl_rect_region_parameter_check(rect_region_def)
+    		    && hdrl_collapse_parameter_is_sigclip(sigclip_def)
+				&& hdrl_collapse_parameter_is_minmax( minmax_def)
+				&& hdrl_collapse_parameter_is_mode(mode_def),
+       		CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+
     char                *   name ;
     cpl_parameterlist   *   parlist = cpl_parameterlist_new();
     cpl_parameter       *   par ;
@@ -402,7 +424,7 @@ cpl_parameterlist * hdrl_overscan_parameter_create_parlist(
     /* --prefix.collapse.xxx */
     name = hdrl_join_string(".", 2, prefix, "collapse");
     cpl_parameterlist * pcollapse = hdrl_collapse_parameter_create_parlist(
-            base_context, name, method_def, sigclip_def, minmax_def) ;
+            base_context, name, method_def, sigclip_def, minmax_def, mode_def) ;
     cpl_free(name);
     for (cpl_parameter * p = cpl_parameterlist_get_first(pcollapse) ;
             p != NULL; p = cpl_parameterlist_get_next(pcollapse))
@@ -439,7 +461,12 @@ cpl_parameterlist * hdrl_overscan_parameter_create_parlist(
   - prefix.collapse.sigclip.kappa-high
   - prefix.collapse.sigclip.niter
   - prefix.collapse.minmax.nlow
-  - prefix.collapse.sigclip.nhigh
+  - prefix.collapse.minmax.nhigh
+  - prefix.collapse.mode.histo-min
+  - prefix.collapse.mode.histo-max
+  - prefix.collapse.mode.bin-size
+  - prefix.collapse.mode.method
+  - prefix.collapse.mode.error_niter
 
  */
 /* ---------------------------------------------------------------------------*/
@@ -448,9 +475,7 @@ hdrl_parameter * hdrl_overscan_parameter_parse_parlist(
         const char              *   prefix)
 {
     cpl_ensure(prefix && parlist, CPL_ERROR_NULL_INPUT, NULL);
-    const cpl_parameter *   par = NULL;
     hdrl_direction          corr_dir_param = HDRL_UNDEFINED_AXIS ;
-    const char          *   correction_direction = NULL;
     int                     box_hsize = 0 ;
     double                  ccd_ron = 0. ;
     hdrl_parameter      *   os_collapse_params = NULL;
@@ -459,8 +484,8 @@ hdrl_parameter * hdrl_overscan_parameter_parse_parlist(
 
     /* --correction-direction */
     name = hdrl_join_string(".", 2, prefix, "correction-direction");
-    par = cpl_parameterlist_find_const(parlist, name) ;
-    correction_direction = cpl_parameter_get_string(par);
+    const cpl_parameter *par = cpl_parameterlist_find_const(parlist, name);
+    const char *correction_direction = cpl_parameter_get_string(par);
     if (correction_direction == NULL) {
         cpl_error_set_message(cpl_func, CPL_ERROR_DATA_NOT_FOUND,
                               "Parameter %s not found", name);
@@ -555,6 +580,16 @@ get_reduction(const hdrl_parameter * cpse,
         if (nlow <= 0)     nlow = 0;
         if (nhigh <= 0)    nhigh = 0;
         *reduce = hdrl_collapse_imagelist_to_vector_minmax(nlow, nhigh);
+	
+    } else if (hdrl_collapse_parameter_is_mode(cpse)) {
+	double histo_min = hdrl_collapse_mode_parameter_get_histo_min(cpse);
+	double histo_max = hdrl_collapse_mode_parameter_get_histo_max(cpse);
+	double bin_size = hdrl_collapse_mode_parameter_get_bin_size(cpse);
+	hdrl_mode_type method = hdrl_collapse_mode_parameter_get_method(cpse);
+	cpl_size error_niter = hdrl_collapse_mode_parameter_get_error_niter(cpse);
+	*reduce = hdrl_collapse_imagelist_to_vector_mode(histo_min, histo_max,
+							 bin_size, method,
+							 error_niter);
     }
 
     return cpl_error_get_code();
@@ -672,6 +707,12 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
             return NULL, "NULL input image");
     cpl_error_ensure(params != NULL, CPL_ERROR_NULL_INPUT, 
             return NULL, "NULL input parameters");
+
+	int d1 = sizeof(hdrl_sigclip_vector_output);
+	int d2 = sizeof(hdrl_minmax_vector_output );
+    cpl_error_ensure(d1 == d2, CPL_ERROR_INVALID_TYPE, return NULL,
+		"Invalid check type between hdrl_sigclip_vector_output and hdrl_minmax_vector_output");
+
     if (hdrl_overscan_parameter_verify(
                 params,
                 cpl_image_get_size_x(source),
@@ -680,7 +721,7 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
 
     /* Local Usage Parameters */
     const hdrl_overscan_parameter * p_loc = 
-        (hdrl_overscan_parameter *)params ;
+        (const hdrl_overscan_parameter *)params ;
     const hdrl_parameter * cpse = p_loc->collapse ;
     const hdrl_parameter * rr = p_loc->rect_region ;
 
@@ -716,7 +757,6 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
         reject_high = cpl_image_new(1, ury, CPL_TYPE_DOUBLE);
     }
 
-
     /* Loop along Y direction */
     /* only 1 iteration if hbox == HDRL_OVERSCAN_FULL_BOX */
 HDRL_OMP(omp parallel for)
@@ -765,19 +805,23 @@ HDRL_OMP(omp parallel for)
         /* Compute the over-scan correction, error, and contribution  */
         hdrl_overscan_reduce_image_to_scalar(reduce, overscan_sub_ima, 
                 ccd_ron_ima, &corr, &error, &contribution, &collapse_eout);
+
         /* handle additional sigclip and minmax output */
         if (collapse_eout && (hdrl_collapse_parameter_is_sigclip(cpse) ||
             hdrl_collapse_parameter_is_minmax(cpse))) {
-            assert(sizeof(hdrl_sigclip_vector_output) ==
-                   sizeof(hdrl_minmax_vector_output));
+
             hdrl_sigclip_vector_output * eout = collapse_eout;
-            double low = cpl_vector_get(eout->reject_low, 0);
+
+            double low  = cpl_vector_get(eout->reject_low, 0);
             double high = cpl_vector_get(eout->reject_high, 0);
+
             cpl_image_set(reject_low, 1, ipixel, low);
             cpl_image_set(reject_high, 1, ipixel, high);
+
             cpl_vector_delete(eout->reject_low);
             cpl_vector_delete(eout->reject_high);
         }
+
         hdrl_collapse_imagelist_to_vector_unwrap_eout(reduce, collapse_eout);
 
         /* Compute the chi2 - Independent of the method */
@@ -1192,7 +1236,7 @@ void hdrl_overscan_compute_result_delete(
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Overscan correction 
-  @param    hsource         Input HDRL image that needs to be corrected
+  @param    source          Input HDRL image that needs to be corrected
   @param    region          Region from source that needs correction
   @param    os_computation  Results of the Overscan computation
   @return  hdrl_overscan_correct_result structure containing the
@@ -1240,7 +1284,7 @@ void hdrl_overscan_compute_result_delete(
  */
 /*----------------------------------------------------------------------------*/
 hdrl_overscan_correct_result * hdrl_overscan_correct(
-        const hdrl_image                    *   hsource,
+        const hdrl_image                    *   source,
         const hdrl_parameter                *   region,
         const hdrl_overscan_compute_result  *   os_computation)
 {
@@ -1257,7 +1301,7 @@ hdrl_overscan_correct_result * hdrl_overscan_correct(
     hdrl_bitmask_t      reject_code = 1;
 
     /* Check Entries */
-    cpl_error_ensure(hsource != NULL, CPL_ERROR_NULL_INPUT,
+    cpl_error_ensure(source != NULL, CPL_ERROR_NULL_INPUT,
             return NULL, "NULL input source image");
     cpl_error_ensure(os_computation != NULL, CPL_ERROR_NULL_INPUT,
             return NULL, "NULL overscan computation result");
@@ -1274,8 +1318,8 @@ hdrl_overscan_correct_result * hdrl_overscan_correct(
     /* Initialise Region parameters */
     if (region != NULL) {
         if (hdrl_rect_region_parameter_verify(region, 
-                    hdrl_image_get_size_x(hsource),
-                    hdrl_image_get_size_y(hsource)) != CPL_ERROR_NONE)
+                    hdrl_image_get_size_x(source),
+                    hdrl_image_get_size_y(source)) != CPL_ERROR_NONE)
             return NULL;
         llx = hdrl_rect_region_get_llx(region);
         lly = hdrl_rect_region_get_lly(region);
@@ -1283,14 +1327,14 @@ hdrl_overscan_correct_result * hdrl_overscan_correct(
         ury = hdrl_rect_region_get_ury(region);
     } else {
         llx = lly = 1;
-        urx = hdrl_image_get_size_x(hsource);
-        ury = hdrl_image_get_size_y(hsource);
+        urx = hdrl_image_get_size_x(source);
+        ury = hdrl_image_get_size_y(source);
     }
 
     source_loc =
-        cpl_image_cast(hdrl_image_get_image_const(hsource), HDRL_TYPE_DATA);
+        cpl_image_cast(hdrl_image_get_image_const(source), HDRL_TYPE_DATA);
     source_error_loc =
-        cpl_image_cast(hdrl_image_get_error_const(hsource), HDRL_TYPE_ERROR);
+        cpl_image_cast(hdrl_image_get_error_const(source), HDRL_TYPE_ERROR);
     nx = cpl_image_get_size_x(source_loc);
 
     xsize_overscan = hdrl_image_get_size_x(hoverscan);
@@ -1314,8 +1358,12 @@ hdrl_overscan_correct_result * hdrl_overscan_correct(
         return NULL;
     }
 
-    cpl_ensure(xsize_overscan == 1 || ysize_overscan == 1,
-               CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+    if (xsize_overscan != 1 && ysize_overscan != 1) {
+        cpl_image_delete(source_loc);
+        cpl_image_delete(source_error_loc);
+        cpl_error_set(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT);
+        return NULL;
+    }
 
     /* store original mask to later separate it from newly created bpms */
     orig_mask = hdrl_copy_image_mask(source_loc);
