@@ -26,17 +26,31 @@
                                 Includes
  -----------------------------------------------------------------------------*/
 
+#include "hdrl_prototyping.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
 #include <errno.h>
 #include <complex.h>
-#include <hdrl_prototyping.h>
+/*----------------------------------------------------------------------------*/
+/**
+ * @defgroup hdrl_prototyping   Prototyping object (derived from MIME project)
+ *
+ * This module contains functions derived from MIME project, adapted to HDRL.
+ * @internal
+ * see hdrl_prototyping-test.c for an example usage
+ */
+/*----------------------------------------------------------------------------*/
 
 /*-----------------------------------------------------------------------------
                                 Defines
  -----------------------------------------------------------------------------*/
-#define freeimage(_p) if (_p != NULL) {cpl_image_delete(_p); _p = NULL;}
+/*-----------------------------------------------------------------------------
+                                   Functions
+ -----------------------------------------------------------------------------*/
+
+/**@{*/
 
 
 /*-----------------------------------------------------------------------------
@@ -68,8 +82,8 @@ cpl_image * hdrl_get_spatial_freq(cpl_image *ima, double gausfilt, int mirrorx,
     double sigma_x = 0.;
     double sigma_y = 0.;
 
-    cpl_image *clean_flat=NULL;
-    cpl_image *eflat=NULL;
+    cpl_image *clean_flat;
+    cpl_image *eflat;
     cpl_image *eflat_complex=NULL;
     cpl_image *eflat_real=NULL;
 
@@ -90,14 +104,17 @@ cpl_image * hdrl_get_spatial_freq(cpl_image *ima, double gausfilt, int mirrorx,
 
     /* Expand the flat image using the mirror edges function */
     eflat = hdrl_mirror_edges(clean_flat, mirrorx, mirrory);
+
+	if (clean_flat != NULL) {
+		cpl_image_delete(clean_flat);
+		clean_flat = NULL;
+	}
+
     if(eflat == NULL){
-        freeimage(clean_flat);
         cpl_msg_error(cpl_func,"Filter image is NULL");
         return NULL;
     }
 
-    freeimage(clean_flat);
-
     xsize = cpl_image_get_size_x(eflat);
     ysize = cpl_image_get_size_y(eflat);
 
@@ -363,17 +380,11 @@ cpl_error_code hdrl_mime_compute_polynomial_bkg(
                   dim_X, dim_Y);
 
     /* Sanity Check of input data, and parameters */
+    cpl_error_ensure(images != NULL, CPL_ERROR_DATA_NOT_FOUND,
+        	return CPL_ERROR_DATA_NOT_FOUND, "list of dithered images is empty");
 
-    if (images == NULL) {
-        cpl_msg_error(cpl_func, "list of dithered images is empty") ;
-        return cpl_error_set(cpl_func, CPL_ERROR_DATA_NOT_FOUND);
-    }
-
-    if (cpl_imagelist_is_uniform(images) != 0) {
-        cpl_msg_error(cpl_func, "input image list have non uniform data") ;
-        return cpl_error_set(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT);
-    }
-
+    cpl_error_ensure(cpl_imagelist_is_uniform(images) == 0, CPL_ERROR_INCOMPATIBLE_INPUT,
+        	return CPL_ERROR_INCOMPATIBLE_INPUT, "input image list have non uniform data");
 
     /*
        Compute Dimensions
