@@ -43,6 +43,7 @@
 typedef enum {
     HDRL_OSCAN_COLLAPSE_TEST_MEAN,
     HDRL_OSCAN_COLLAPSE_TEST_MEDIAN,
+	HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN,
     HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP,
     HDRL_OSCAN_COLLAPSE_TEST_MINMAX
 } hdrl_oscan_collapse_test ;
@@ -63,14 +64,23 @@ void test_parlist(void)
         hdrl_collapse_sigclip_parameter_create(3., 3., 5);
     hdrl_parameter * minmax_def =
         hdrl_collapse_minmax_parameter_create(2., 3.);
+    hdrl_parameter * mode_def =
+        hdrl_collapse_mode_parameter_create(10., 1., 0., HDRL_MODE_MEDIAN, 0);
+
     cpl_parameterlist * pos = hdrl_overscan_parameter_create_parlist(
                 "RECIPE", "oscan", "alongX", 10, 10., rect_region_def,
-                "MINMAX", sigclip_def, minmax_def);
+                "MINMAX", sigclip_def, minmax_def, mode_def);
+    hdrl_parameter_delete(mode_def);
     hdrl_parameter_delete(sigclip_def);
     hdrl_parameter_delete(minmax_def);
     hdrl_parameter_delete(rect_region_def);
     cpl_test_error(CPL_ERROR_NONE);
-    cpl_test_eq(cpl_parameterlist_get_size(pos), 13);
+    /*
+        Before adding the mode method:
+        cpl_test_eq(cpl_parameterlist_get_size(pos), 13);
+    */
+
+    cpl_test_eq(cpl_parameterlist_get_size(pos), 13 + 5);
 
     hpar = hdrl_overscan_parameter_parse_parlist(pos, "RECIPE.invalid");
     cpl_test_null(hpar);
@@ -109,16 +119,17 @@ void test_parlist(void)
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_null_input(void)
 {
-    hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   overscan_computation = NULL;
+    hdrl_parameter                  *   os_region;
+    hdrl_parameter                  *   os_collapse;
+    hdrl_parameter                  *   os_param;
+    hdrl_overscan_compute_result    *   overscan_computation;
 
     /* Overscan Parameters */
     os_region = hdrl_rect_region_parameter_create(1, 1, 1, 1) ;
     os_collapse = hdrl_collapse_mean_parameter_create() ;
     os_param = hdrl_overscan_parameter_create(HDRL_Y_AXIS, 1., 1, 
             os_collapse, os_region) ;
+    cpl_test(hdrl_overscan_parameter_check(os_param));
 
     /* test functionality */
     overscan_computation = hdrl_overscan_compute(NULL, os_param) ;
@@ -140,11 +151,11 @@ static cpl_error_code hdrl_overscan_test_null_input(void)
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_null_region(void)
 {
-    cpl_image                       *   image_data = NULL;
+    cpl_image                       *   image_data;
     hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   overscan_computation = NULL;
+    hdrl_parameter                  *   os_collapse;
+    hdrl_parameter                  *   os_param;
+    hdrl_overscan_compute_result    *   overscan_computation;
 
     /* create input structures (on purpose not the input region) */
     image_data = cpl_image_new(1, 1, CPL_TYPE_DOUBLE);
@@ -174,11 +185,11 @@ static cpl_error_code hdrl_overscan_test_null_region(void)
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_null_sigclip(void)
 {
-    cpl_image                       *   image_data = NULL;
-    hdrl_parameter                  *   os_region = NULL;
+    cpl_image                       *   image_data;
+    hdrl_parameter                  *   os_region;
     hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   overscan_computation = NULL;
+    hdrl_parameter                  *   os_param;
+    hdrl_overscan_compute_result    *   overscan_computation;
 
     /* create input structures (on purpose not the input region) */
     image_data = cpl_image_new(1, 1, CPL_TYPE_DOUBLE);
@@ -209,7 +220,7 @@ static cpl_error_code hdrl_overscan_test_null_sigclip(void)
 static cpl_error_code hdrl_overscan_test_null_params(void)
 {
     cpl_image* image_data = cpl_image_new(1, 1, CPL_TYPE_DOUBLE);
-    hdrl_overscan_compute_result * overscan_computation = NULL;
+    hdrl_overscan_compute_result * overscan_computation;
 
     /* test functionality */
     overscan_computation = hdrl_overscan_compute(image_data, NULL);
@@ -229,11 +240,11 @@ static cpl_error_code hdrl_overscan_test_null_params(void)
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_wrong_region(void)
 {
-    hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    cpl_image                       *   image_data = NULL;
-    hdrl_overscan_compute_result    *   computation = NULL;
+    hdrl_parameter                  *   os_region;
+    hdrl_parameter                  *   os_collapse;
+    hdrl_parameter                  *   os_param;
+    cpl_image                       *   image_data;
+    hdrl_overscan_compute_result    *   computation;
 
     /* create input image  */
     image_data = cpl_image_new(5, 10, CPL_TYPE_DOUBLE);
@@ -278,14 +289,14 @@ static cpl_error_code hdrl_overscan_test_wrong_region(void)
 static double hdrl_overscan_test_uniform_image(const double inp_value)
 {
     double                              out_value = 0;
-    cpl_image                       *   image_data = NULL;
-    cpl_image                       *   image_errs = NULL;
+    cpl_image                       *   image_data;
+    cpl_image                       *   image_errs;
     hdrl_image                      *   image;
-    hdrl_overscan_compute_result    *   comp_res = NULL;
-    hdrl_overscan_correct_result    *   overscan_correction = NULL;
-    hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
+    hdrl_overscan_compute_result    *   comp_res;
+    hdrl_overscan_correct_result    *   overscan_correction;
+    hdrl_parameter                  *   os_region;
+    hdrl_parameter                  *   os_collapse;
+    hdrl_parameter                  *   os_param;
 
     /* Create input structures (on purpose not the input region) */
     image_data = cpl_image_new(100, 100, HDRL_TYPE_DATA);
@@ -533,7 +544,7 @@ static cpl_error_code hdrl_overscan_test_full_hbox(
     hdrl_parameter                  *   os_region = NULL;
     hdrl_parameter                  *   os_collapse = NULL;
     hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   res_os_comp = NULL;
+    hdrl_overscan_compute_result    *   res_os_comp;
     hdrl_overscan_correct_result    *   res_os_cor = NULL;
 
     /* sets overscan to use full region and emit single pixel value */
@@ -550,44 +561,48 @@ static cpl_error_code hdrl_overscan_test_full_hbox(
     cpl_image_power(image_errs, 0.5);
 
     /* Overscan Parameters */
-    os_region = hdrl_rect_region_parameter_create(1, 1, Nx, Ny) ;
-    os_collapse = hdrl_collapse_mean_parameter_create() ;
+    os_region   = hdrl_rect_region_parameter_create(1, 1, Nx, Ny);
+    os_collapse = hdrl_collapse_mean_parameter_create();
+
     /* invalid boxsize */
     os_param = hdrl_overscan_parameter_create(HDRL_Y_AXIS,
-            error * sqrt(Nx * Ny), -2, os_collapse, os_region) ;
+            error * sqrt(Nx * Ny), -2, os_collapse, os_region);
 
-    res_os_comp = hdrl_overscan_compute(image_data, os_param);
+    hdrl_overscan_compute(image_data, os_param);
     cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
 
     /* test compute y direction */
-    hdrl_parameter_delete(os_param) ;
+    hdrl_parameter_delete(os_param);
     os_param = hdrl_overscan_parameter_create(HDRL_Y_AXIS,
-            error * sqrt(Nx * Ny), HDRL_OVERSCAN_FULL_BOX, 
-            os_collapse, os_region) ;
+											  error * sqrt(Nx * Ny),
+											  HDRL_OVERSCAN_FULL_BOX,
+											  os_collapse, os_region);
     res_os_comp = hdrl_overscan_compute(image_data, os_param);
 
-    hdrl_parameter_delete(os_region) ;
-    hdrl_parameter_delete(os_collapse) ;
-    hdrl_parameter_delete(os_param) ;
+    hdrl_parameter_delete(os_region);
+    hdrl_parameter_delete(os_collapse);
+    hdrl_parameter_delete(os_param);
 
     cpl_test_error(CPL_ERROR_NONE);
 
     {
         /* we expect a row with all the same overscan value */
         hdrl_image * ex = hdrl_image_new(Nx, 1);
+
         hdrl_image_add_scalar(ex, (hdrl_value){(Nx - 1.) / 2., error});
+
         /* cpl mean implementation has a rather large error */
         hdrl_test_image_abs(ex, res_os_comp->correction,
-                            2 * Nx * Ny * HDRL_EPS_DATA);
-
+        						2 * Nx * Ny * HDRL_EPS_DATA);
         hdrl_test_image_abs(ex, res_os_comp->correction,
-                           Nx * Ny * HDRL_EPS_DATA);
+        						Nx * Ny * HDRL_EPS_DATA);
 
         hdrl_image_delete(ex);
     }
 
     hdrl_overscan_compute_result_delete(res_os_comp);
     hdrl_overscan_correct_result_delete(res_os_cor);
+
     hdrl_image_delete(image);
 
     return cpl_error_get_code();
@@ -605,18 +620,52 @@ static cpl_error_code hdrl_overscan_test_turn_eq(
         int                         hbox,
         hdrl_oscan_collapse_test    method)
 {
-    const double                        error = 10;
-    hdrl_image * image = hdrl_image_new(Nx, Ny);
-    hdrl_image * image_t;
+	cpl_ensure_code(method == HDRL_OSCAN_COLLAPSE_TEST_MEAN          ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_MEDIAN        ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP       ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX,
+				    CPL_ERROR_ILLEGAL_INPUT);
+
+    hdrl_parameter *os_collapse = NULL;
+    if (method == HDRL_OSCAN_COLLAPSE_TEST_MEAN) {
+        cpl_msg_info(cpl_func, "Mean method hbox %d, Nx %ld, Ny %ld",
+                     hbox, (long)Nx, (long)Ny);
+        os_collapse = hdrl_collapse_mean_parameter_create();
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MEDIAN) {
+        cpl_msg_info(cpl_func, "Median method hbox %d, Nx %ld, Ny %ld",
+                     hbox, (long)Nx, (long)Ny);
+        os_collapse = hdrl_collapse_median_parameter_create();
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN) {
+        cpl_msg_info(cpl_func, "Weighted Median method hbox %d, Nx %ld, Ny %ld",
+                     hbox, (long)Nx, (long)Ny);
+        os_collapse = hdrl_collapse_weighted_mean_parameter_create();
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP) {
+        cpl_msg_info(cpl_func, "Sigma-Clipping method hbox %d, Nx %ld, Ny %ld",
+                     hbox, (long)Nx, (long)Ny);
+        os_collapse = hdrl_collapse_sigclip_parameter_create(3., 3., 3) ;
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX) {
+        cpl_msg_info(cpl_func, "MinMax method hbox %d, Nx %ld, Ny %ld",
+                     hbox, (long)Nx, (long)Ny);
+        os_collapse = hdrl_collapse_minmax_parameter_create(3, 3);
+    }
+
+
+    const double error = 10;
+
+    hdrl_image *image = hdrl_image_new(Nx, Ny);
+    hdrl_image *image_t;
+
     cpl_image * image_data = hdrl_image_get_image(image);
     cpl_image * image_errs = hdrl_image_get_error(image);
-    hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   res_os_comp = NULL;
-    hdrl_overscan_compute_result    *   res_os_comp_turn = NULL;
-    hdrl_overscan_correct_result    *   res_os_cor = NULL;
-    hdrl_overscan_correct_result    *   res_os_cor_turn = NULL;
+
+    hdrl_parameter *os_region = NULL;
+    hdrl_parameter *os_param  = NULL;
+
+    hdrl_overscan_compute_result *res_os_comp      = NULL;
+    hdrl_overscan_compute_result *res_os_comp_turn = NULL;
+    hdrl_overscan_correct_result *res_os_cor       = NULL;
+    hdrl_overscan_correct_result *res_os_cor_turn  = NULL;
 
     for (cpl_size x = 0; x < Nx; x++) {
         for (cpl_size y = 0; y < Ny; y++) {
@@ -630,24 +679,7 @@ static cpl_error_code hdrl_overscan_test_turn_eq(
     image_t = hdrl_image_duplicate(image);
     hdrl_image_turn(image_t, +1);
     
-    if (method == HDRL_OSCAN_COLLAPSE_TEST_MEAN) {
-        cpl_msg_info(cpl_func, "Mean method hbox %d, Nx %ld, Ny %ld",
-                     hbox, (long)Nx, (long)Ny);
-        os_collapse = hdrl_collapse_mean_parameter_create() ;
-    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MEDIAN) {
-        cpl_msg_info(cpl_func, "Median method hbox %d, Nx %ld, Ny %ld",
-                     hbox, (long)Nx, (long)Ny);
-        os_collapse = hdrl_collapse_median_parameter_create() ;
 
-    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP) {
-        cpl_msg_info(cpl_func, "Sigma-Clipping method hbox %d, Nx %ld, Ny %ld",
-                     hbox, (long)Nx, (long)Ny);
-        os_collapse = hdrl_collapse_sigclip_parameter_create(3.,3.,3) ;
-    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX) {
-        cpl_msg_info(cpl_func, "MinMax method hbox %d, Nx %ld, Ny %ld",
-                     hbox, (long)Nx, (long)Ny);
-        os_collapse = hdrl_collapse_minmax_parameter_create(3, 3);
-    }
 
     /* Overscan Parameters */
     os_region = hdrl_rect_region_parameter_create(1, 1, Nx, Ny) ;
@@ -699,6 +731,25 @@ static cpl_error_code hdrl_overscan_test_turn_eq(
     hdrl_test_image_abs(res_os_cor->corrected, res_os_cor_turn->corrected,
                        (1 + hbox) * Ny * HDRL_EPS_DATA);
 
+	/* Get corrected */
+	hdrl_image *imgCorrected1 = hdrl_overscan_correct_result_get_corrected(res_os_cor);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(imgCorrected1);
+	hdrl_image *imgCorrected2 = hdrl_overscan_correct_result_unset_corrected(res_os_cor);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(imgCorrected2);
+	hdrl_image_delete(imgCorrected2);
+
+	/* Get badmask */
+	cpl_image *cpImgBadMask_1 = hdrl_overscan_correct_result_get_badmask(res_os_cor);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgBadMask_1);
+	cpl_image *cpImgBadMask_2 = hdrl_overscan_correct_result_unset_badmask(res_os_cor);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgBadMask_2);
+	cpl_image_delete(cpImgBadMask_2);
+
+
     hdrl_overscan_compute_result_delete(res_os_comp);
     hdrl_overscan_compute_result_delete(res_os_comp_turn);
     hdrl_overscan_correct_result_delete(res_os_cor);
@@ -718,63 +769,144 @@ static cpl_error_code hdrl_overscan_test_turn_eq(
 static cpl_error_code hdrl_overscan_test_empty_box(
         hdrl_oscan_collapse_test    method)
 {
-    cpl_size                            Nx = 10 ;
-    cpl_size                            Ny = 10;
-    cpl_image * image_data = cpl_image_new(Nx, Ny, HDRL_TYPE_DATA);
-    cpl_image * image_errs = cpl_image_new(Nx, Ny, HDRL_TYPE_ERROR);
-    hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   res_os_comp = NULL;
 
+	cpl_ensure_code(method == HDRL_OSCAN_COLLAPSE_TEST_MEAN          ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_MEDIAN        ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP       ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX,
+					CPL_ERROR_ILLEGAL_INPUT);
 
     /* Overscan Parameters */
-    if (method == HDRL_OSCAN_COLLAPSE_TEST_MEAN) {
+    hdrl_parameter *os_collapse = NULL;
+    if(method == HDRL_OSCAN_COLLAPSE_TEST_MEAN) {
         cpl_msg_info(cpl_func, "check empty box MEAN");
-        os_collapse = hdrl_collapse_mean_parameter_create() ;
+        os_collapse = hdrl_collapse_mean_parameter_create();
     } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MEDIAN) {
         cpl_msg_info(cpl_func, "check empty box MEDIAN");
-        os_collapse = hdrl_collapse_median_parameter_create() ;
+        os_collapse = hdrl_collapse_median_parameter_create();
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN) {
+        cpl_msg_info(cpl_func, "check empty box WEIGHTED_MEAN");
+        os_collapse = hdrl_collapse_weighted_mean_parameter_create();
     } else if (method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP) {
         cpl_msg_info(cpl_func, "check empty box SIGCLIP");
-        os_collapse = hdrl_collapse_sigclip_parameter_create(3.,3.,3) ;
+        os_collapse = hdrl_collapse_sigclip_parameter_create(3., 3., 3);
     } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX) {
         cpl_msg_info(cpl_func, "check empty box MINMAX");
         os_collapse = hdrl_collapse_minmax_parameter_create(3, 3);
     }
-    os_region = hdrl_rect_region_parameter_create(1, 1, Nx, Ny) ;
-    os_param = hdrl_overscan_parameter_create(HDRL_Y_AXIS, 1., 0, 
-            os_collapse, os_region) ;
+
+    cpl_size Nx = 10;
+    cpl_size Ny = 10;
+    cpl_image *image_data = cpl_image_new(Nx, Ny, HDRL_TYPE_DATA);
+
+    hdrl_parameter *os_region = hdrl_rect_region_parameter_create(1, 1, Nx, Ny);
+    hdrl_parameter *os_param  = hdrl_overscan_parameter_create(
+    								HDRL_Y_AXIS, 1., 0, os_collapse, os_region);
 
     /* reject one row (= one box */
     for (cpl_size i = 0; i < Ny; i++) cpl_image_reject(image_data, 2, i + 1);
 
     /* test compute y direction */
+    hdrl_overscan_compute_result *res_os_comp;
     res_os_comp = hdrl_overscan_compute(image_data, os_param);
-    
-    hdrl_parameter_delete(os_region) ;
-    hdrl_parameter_delete(os_collapse) ;
-    hdrl_parameter_delete(os_param) ;
-    
     cpl_test_error(CPL_ERROR_NONE);
 
-    /* expecting bad pixels in the bad box */
-    {
-        int rej;
-        cpl_test_eq(cpl_image_get(res_os_comp->contribution, 2, 1, &rej), 0);
-        cpl_test(hdrl_image_is_rejected(res_os_comp->correction, 2, 1));
-        cpl_test(cpl_image_is_rejected(res_os_comp->red_chi2, 2, 1));
-        if (res_os_comp->sigclip_reject_low) {
-            cpl_test(cpl_image_is_rejected(res_os_comp->sigclip_reject_low,
-                                           2, 1));
-            cpl_test(cpl_image_is_rejected(res_os_comp->sigclip_reject_high,
-                                           2, 1));
-        }
+
+    hdrl_parameter_delete(os_region);
+    hdrl_parameter_delete(os_collapse);
+    hdrl_parameter_delete(os_param);
+    
+
+	int rej;
+	cpl_test_eq(cpl_image_get(res_os_comp->contribution, 2, 1, &rej), 0);
+	cpl_test(hdrl_image_is_rejected(res_os_comp->correction, 2, 1));
+	cpl_test(cpl_image_is_rejected(res_os_comp->red_chi2, 2, 1));
+
+	/* Get correction */
+	hdrl_image *img1 = hdrl_overscan_compute_result_get_correction(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(img1);
+	hdrl_image *img2 = hdrl_overscan_compute_result_unset_correction(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(img2);
+	hdrl_image_delete(img2);
+
+	/* Get contribution */
+	cpl_image *cpImg1 = hdrl_overscan_compute_result_get_contribution(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImg1);
+	cpl_image *cpImg2 = hdrl_overscan_compute_result_unset_contribution(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImg2);
+	cpl_image_delete(cpImg2);
+
+	/* Get chi2 */
+	cpl_image *cpImgCh2_1 = hdrl_overscan_compute_result_get_chi2(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgCh2_1);
+	cpl_image *cpImgCh2_2 = hdrl_overscan_compute_result_unset_chi2(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgCh2_2);
+	cpl_image_delete(cpImgCh2_2);
+
+	/* Get red chi2 */
+	cpl_image *cpImgRedCh2_1 = hdrl_overscan_compute_result_get_red_chi2(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgRedCh2_1);
+	cpl_image *cpImgRedCh2_2 = hdrl_overscan_compute_result_unset_red_chi2(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgRedCh2_2);
+	cpl_image_delete(cpImgRedCh2_2);
+
+
+    /* Overscan Parameters - SigClip and MinMax*/
+
+	if (method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP) {
+
+    	/* Get overscan SigClip Low */
+    	cpl_image *cpImgSGLow_1 = hdrl_overscan_compute_result_get_sigclip_reject_low(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgSGLow_1);
+    	cpl_image *cpImgSGLow_2 = hdrl_overscan_compute_result_unset_sigclip_reject_low(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgSGLow_2);
+    	cpl_image_delete(cpImgSGLow_2);
+
+    	/* Get overscan SigClip High */
+    	cpl_image *cpImgSGHigh_1 = hdrl_overscan_compute_result_get_sigclip_reject_high(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgSGHigh_1);
+    	cpl_image *cpImgSGHigh_2 = hdrl_overscan_compute_result_unset_sigclip_reject_high(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgSGHigh_2);
+    	cpl_image_delete(cpImgSGHigh_2);
+
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX) {
+
+    	/* Get overscan MinMax Low */
+    	cpl_image *cpImgMMLow_1 = hdrl_overscan_compute_result_get_minmax_reject_low(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgMMLow_1);
+    	cpl_image *cpImgMMLow_2 = hdrl_overscan_compute_result_unset_minmax_reject_low(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgMMLow_2);
+    	cpl_image_delete(cpImgMMLow_2);
+
+    	/* Get overscan MinMax High */
+    	cpl_image *cpImgMMHigh_1 = hdrl_overscan_compute_result_get_minmax_reject_high(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgMMHigh_1);
+    	cpl_image *cpImgMMHigh_2 = hdrl_overscan_compute_result_unset_minmax_reject_high(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgMMHigh_2);
+    	cpl_image_delete(cpImgMMHigh_2);
     }
 
     hdrl_overscan_compute_result_delete(res_os_comp);
+
     cpl_image_delete(image_data);
-    cpl_image_delete(image_errs);
+
 
     return cpl_error_get_code();
 }
@@ -819,6 +951,9 @@ int main(void)
     cpl_size anx[] = {97,  45, 200};
     cpl_size any[] = {575, 34, 200};
 
+    hdrl_overscan_test_turn_eq(0, 0, 0, -1);
+    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+
     for (size_t i = 0; i < sizeof(anx) / sizeof(anx[0]); i++) {
         cpl_size nx = anx[i];
         cpl_size ny = any[i];
@@ -828,23 +963,41 @@ int main(void)
         }
 
         for (int hbox = 0; hbox < 6; hbox+=2) {
+
             hdrl_overscan_test_turn_eq(nx, ny, hbox,
-                    HDRL_OSCAN_COLLAPSE_TEST_MEAN);
+            					       HDRL_OSCAN_COLLAPSE_TEST_MEAN);
+            cpl_test_error(CPL_ERROR_NONE);
             hdrl_overscan_test_turn_eq(nx, ny, hbox,
-                    HDRL_OSCAN_COLLAPSE_TEST_MEDIAN);
+            		                   HDRL_OSCAN_COLLAPSE_TEST_MEDIAN);
+            cpl_test_error(CPL_ERROR_NONE);
             hdrl_overscan_test_turn_eq(nx, ny, hbox,
-                    HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP);
+            							HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN);
+            cpl_test_error(CPL_ERROR_NONE);
             hdrl_overscan_test_turn_eq(nx, ny, hbox,
-                    HDRL_OSCAN_COLLAPSE_TEST_MINMAX);
+            		                   HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP);
+            cpl_test_error(CPL_ERROR_NONE);
+            hdrl_overscan_test_turn_eq(nx, ny, hbox,
+            		                   HDRL_OSCAN_COLLAPSE_TEST_MINMAX);
+            cpl_test_error(CPL_ERROR_NONE);
         }
 
         hdrl_overscan_test_full_hbox(nx, ny);
     }
 
+    hdrl_overscan_test_empty_box(-1);
+    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
     hdrl_overscan_test_empty_box(HDRL_OSCAN_COLLAPSE_TEST_MEAN);
+    cpl_test_error(CPL_ERROR_NONE);
     hdrl_overscan_test_empty_box(HDRL_OSCAN_COLLAPSE_TEST_MEDIAN);
+    cpl_test_error(CPL_ERROR_NONE);
+    hdrl_overscan_test_empty_box(HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN);
+    cpl_test_error(CPL_ERROR_NONE);
     hdrl_overscan_test_empty_box(HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP);
+    cpl_test_error(CPL_ERROR_NONE);
     hdrl_overscan_test_empty_box(HDRL_OSCAN_COLLAPSE_TEST_MINMAX);
+    cpl_test_error(CPL_ERROR_NONE);
+
+
 
     /** \todo Test expected results with uniform frame + spikes */
     //cpl_test(hdrl_overscan_test_uniform_image_and_outliers(),value);
