@@ -1530,13 +1530,13 @@ static int vimos_std_save_simple(casu_fits *obj, cpl_frameset *framelist,
                                      "TRUE if resulting from multiple epochs");
         cpl_propertylist_update_string(plist,"REFERENC","");
         cpl_propertylist_set_comment(plist,"REFERENC","Bibliographic Reference");
-        if (cpl_propertylist_get_bool(casu_fits_get_ehu(obj),"ZPFUDGED")) {
-            cpl_propertylist_update_string(plist,"FLUXCAL","UNCALIBRATED");
-        } else {
-            cpl_propertylist_update_string(plist,"FLUXCAL","ABSOLUTE");
-        }
-        cpl_propertylist_set_comment(plist,"FLUXCAL",
-                                     "Certifies the validity of PHOTZP");
+        //if (cpl_propertylist_get_bool(casu_fits_get_ehu(obj),"ZPFUDGED")) {
+        //    cpl_propertylist_update_string(plist,"FLUXCAL","UNCALIBRATED");
+        //} else {
+        //    cpl_propertylist_update_string(plist,"FLUXCAL","ABSOLUTE");
+        //}
+        //cpl_propertylist_set_comment(plist,"FLUXCAL",
+        //                             "Certifies the validity of PHOTZP");
         cpl_propertylist_update_double(plist,"DIT",(double)texp);
         cpl_propertylist_set_comment(plist,"DIT","Detector integration time");
 
