@@ -56,6 +56,7 @@
 #include "vmimgutils.h"
 #include "vmqcutils.h"
 #include "vmcpl.h"
+#include "vimos_dfs.h"
 
 
 #define SOME_PERCENT (0.01)
@@ -890,7 +891,7 @@ vmdark(PilSetOfFrames *sof)
 
   error = 1;
 
-  if ((darkList = (VimosImage **)pil_calloc(darkCount, sizeof(VimosImage *)))) {
+  if ((darkList = (VimosImage **)cpl_calloc(darkCount, sizeof(VimosImage *)))) {
 
     error = 0;
     currFrame = pilSofLookupNext(sof, darkTag);
@@ -905,7 +906,7 @@ vmdark(PilSetOfFrames *sof)
         cpl_msg_error(task, "Failure opening dark frame %d", i + 1);
         for (j = 0; j < i; j++) 
           deleteImage(darkList[j]);
-        pil_free(darkList);
+        cpl_free(darkList);
         break;
       }
       currFrame = pilSofLookupNext(sof, NULL);
@@ -934,7 +935,7 @@ vmdark(PilSetOfFrames *sof)
     cpl_msg_error(task, "Failure in growing overscans in master bias");
     for (i = 0; i < darkCount; i++) 
       deleteImage(darkList[i]);
-    pil_free(darkList);
+    cpl_free(darkList);
     deleteImage(mBiasImage);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
@@ -947,7 +948,7 @@ vmdark(PilSetOfFrames *sof)
 
   error = 1;
 
-  if ((exposureTime = (float *)pil_calloc(darkCount, sizeof(float)))) {
+  if ((exposureTime = (float *)cpl_calloc(darkCount, sizeof(float)))) {
     error = 0;
     for (i = 0; i < darkCount; i++) {
       if ((readDoubleDescriptor(darkList[i]->descs, 
@@ -957,7 +958,7 @@ vmdark(PilSetOfFrames *sof)
           error = 1;
           cpl_msg_error(task, 
             "Zero or negative exposure time for dark %d", i + 1);
-          pil_free(exposureTime);
+          cpl_free(exposureTime);
           break;
         }
         else {
@@ -968,7 +969,7 @@ vmdark(PilSetOfFrames *sof)
         error = 1;
         cpl_msg_error(task, "Cannot read %s from dark frame %d", 
                     pilTrnGetKeyword("ExposureTime"), i + 1);
-        pil_free(exposureTime);
+        cpl_free(exposureTime);
         break;
       }
     }
@@ -979,7 +980,7 @@ vmdark(PilSetOfFrames *sof)
   if (error) {
     for (j = 0; j < darkCount; j++)
       deleteImage(darkList[j]);
-    pil_free(darkList);
+    cpl_free(darkList);
     deleteImage(mBiasImage);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
@@ -992,7 +993,7 @@ vmdark(PilSetOfFrames *sof)
 
   error = 1;
 
-  if ((darkGain = (float *)pil_calloc(darkCount, sizeof(float)))) {
+  if ((darkGain = (float *)cpl_calloc(darkCount, sizeof(float)))) {
     error = 0;
     for (i = 0; i < darkCount; i++) {
       gain = getMeanGainFactor(darkList[i]);
@@ -1002,7 +1003,7 @@ vmdark(PilSetOfFrames *sof)
       else {
         error = 1;
         cpl_msg_error(task, "Wrong or no gain factor for dark %d", i + 1);
-        pil_free(darkGain);
+        cpl_free(darkGain);
         break;
       }
     }
@@ -1013,8 +1014,8 @@ vmdark(PilSetOfFrames *sof)
   if (error) {
     for (j = 0; j < darkCount; j++)
       deleteImage(darkList[j]);
-    pil_free(darkList);
-    pil_free(exposureTime);
+    cpl_free(darkList);
+    cpl_free(exposureTime);
     deleteImage(mBiasImage);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
@@ -1027,7 +1028,7 @@ vmdark(PilSetOfFrames *sof)
   * is applied.
   */
 
-  if ((darkRon = (float *)pil_calloc(darkCount, sizeof(float)))) {
+  if ((darkRon = (float *)cpl_calloc(darkCount, sizeof(float)))) {
     for (i = 0; i < darkCount; i++) {
       darkRon[i] = computeAverageRon(darkList[i]);
     }
@@ -1037,15 +1038,15 @@ vmdark(PilSetOfFrames *sof)
 
     for (i = 0; i < darkCount; i++)
       deleteImage(darkList[i]);
-    pil_free(darkList);
-    pil_free(exposureTime);
-    pil_free(darkGain);
+    cpl_free(darkList);
+    cpl_free(exposureTime);
+    cpl_free(darkGain);
     deleteImage(mBiasImage);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
   }
 
-  if ((darkNoise = (float *)pil_calloc(darkCount, sizeof(float)))) {
+  if ((darkNoise = (float *)cpl_calloc(darkCount, sizeof(float)))) {
     for (i = 0; i < darkCount; i++) {
       darkNoise[i] = evaluateAverageNoise(darkList[i], 
                      darkRon[i], darkGain[i]);
@@ -1056,10 +1057,10 @@ vmdark(PilSetOfFrames *sof)
 
     for (i = 0; i < darkCount; i++)
       deleteImage(darkList[i]);
-    pil_free(darkList);
-    pil_free(exposureTime);
-    pil_free(darkGain);
-    pil_free(darkRon);
+    cpl_free(darkList);
+    cpl_free(exposureTime);
+    cpl_free(darkGain);
+    cpl_free(darkRon);
     deleteImage(mBiasImage);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
@@ -1068,6 +1069,13 @@ vmdark(PilSetOfFrames *sof)
 
  /*
   * Now go for the bias subtraction
+  * 
+  * NOTE: This includes the overscan subtraction if biasMethod = BIAS_ZMASTER,
+  * which is the default. Since the overscan region in the master bias has 
+  * been created with growOverscans, there is some extra noise added here,
+  * but this can probably be ignored. A better approach is to use the method
+  * used in the MOS pipeline: subtract overscan for each individual frame,
+  * then subtract bias.
   */
 
   cpl_msg_info(task, "Bias removal...");
@@ -1077,11 +1085,11 @@ vmdark(PilSetOfFrames *sof)
       cpl_msg_error(task, "Cannot remove bias from input dark %d", i + 1);
       for (i = 0; i < darkCount; i++)
         deleteImage(darkList[i]);
-      pil_free(darkList);
-      pil_free(exposureTime);
-      pil_free(darkGain);
-      pil_free(darkRon);
-      pil_free(darkNoise);
+      cpl_free(darkList);
+      cpl_free(exposureTime);
+      cpl_free(darkGain);
+      cpl_free(darkRon);
+      cpl_free(darkNoise);
       deleteImage(mBiasImage);
       deleteCcdTable(ccdTable);
       return EXIT_FAILURE;
@@ -1095,7 +1103,7 @@ vmdark(PilSetOfFrames *sof)
   * Now dark levels can be computed
   */
 
-  if ((darkLevel = (float *)pil_calloc(darkCount, sizeof(float)))) {
+  if ((darkLevel = (float *)cpl_calloc(darkCount, sizeof(float)))) {
     for (i = 0; i < darkCount; i++) {
       darkLevel[i] = imageMedian(darkList[i]);
       cpl_msg_info(task, "Level of dark %-d is %10.4f +/- %-.4f ADU",
@@ -1106,11 +1114,11 @@ vmdark(PilSetOfFrames *sof)
     cpl_msg_error(task, "Problems with memory allocation");
     for (i = 0; i < darkCount; i++)
       deleteImage(darkList[i]);
-    pil_free(darkList);
-    pil_free(darkGain);
-    pil_free(darkRon);
-    pil_free(darkNoise);
-    pil_free(exposureTime);
+    cpl_free(darkList);
+    cpl_free(darkGain);
+    cpl_free(darkRon);
+    cpl_free(darkNoise);
+    cpl_free(exposureTime);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
   }
@@ -1132,12 +1140,12 @@ vmdark(PilSetOfFrames *sof)
                     "Cannot clean cosmic rays from raw dark frame %d", i + 1);
         for (i = 0; i < darkCount; i++)
           deleteImage(darkList[i]);
-        pil_free(darkList);
-        pil_free(darkNoise);
-        pil_free(darkGain);
-        pil_free(darkRon);
-        pil_free(darkLevel);
-        pil_free(exposureTime);
+        cpl_free(darkList);
+        cpl_free(darkNoise);
+        cpl_free(darkGain);
+        cpl_free(darkRon);
+        cpl_free(darkLevel);
+        cpl_free(exposureTime);
         deleteCcdTable(ccdTable);
         return EXIT_FAILURE;
       }
@@ -1145,8 +1153,8 @@ vmdark(PilSetOfFrames *sof)
     }
   }
 
-  pil_free(darkRon);
-  pil_free(darkGain);
+  cpl_free(darkRon);
+  cpl_free(darkGain);
 
 
  /*
@@ -1208,7 +1216,7 @@ vmdark(PilSetOfFrames *sof)
     lowerThreshold = medianLevel - levelThreshold;
     upperThreshold = medianLevel + levelThreshold;
 
-    original = (VimosImage **)pil_calloc(darkCount, sizeof(VimosImage *));
+    original = (VimosImage **)cpl_calloc(darkCount, sizeof(VimosImage *));
     if (original) {
       for (i = 0; i < darkCount; i++)
         original[i] = darkList[i];     /* Hold original image sorting */
@@ -1241,11 +1249,11 @@ vmdark(PilSetOfFrames *sof)
         cpl_msg_error(task, "Problems remapping arrays after frame selection");
         for (i = 0; i < darkCount; i++)
           deleteImage(darkList[i]);
-        pil_free(darkList);
-        pil_free(original);
-        pil_free(darkNoise);
-        pil_free(darkLevel);
-        pil_free(exposureTime);
+        cpl_free(darkList);
+        cpl_free(original);
+        cpl_free(darkNoise);
+        cpl_free(darkLevel);
+        cpl_free(exposureTime);
         deleteCcdTable(ccdTable);
         return EXIT_FAILURE;
       }
@@ -1279,11 +1287,11 @@ vmdark(PilSetOfFrames *sof)
         cpl_msg_error(task, "Problems remapping arrays after frame selection");
         for (i = 0; i < darkCount; i++)
           deleteImage(darkList[i]);
-        pil_free(darkList);
-        pil_free(original);
-        pil_free(darkNoise);
-        pil_free(darkLevel);
-        pil_free(exposureTime);
+        cpl_free(darkList);
+        cpl_free(original);
+        cpl_free(darkNoise);
+        cpl_free(darkLevel);
+        cpl_free(exposureTime);
         deleteCcdTable(ccdTable);
         return EXIT_FAILURE;
       }
@@ -1295,7 +1303,7 @@ vmdark(PilSetOfFrames *sof)
            goodFrames, darkCount);
     }
 
-    pil_free(original);
+    cpl_free(original);
 
   }
   else 
@@ -1308,14 +1316,14 @@ vmdark(PilSetOfFrames *sof)
 
   for (i = goodFrames; i < darkCount; i++)
     deleteImage(darkList[i]);
-  pil_free(darkNoise);
-  pil_free(darkLevel);
+  cpl_free(darkNoise);
+  cpl_free(darkLevel);
 
   if (!goodFrames) {
     cpl_msg_error(task, "No dark frames with consistent signal "
                 "distribution found in input. All frames excluded!");
-    pil_free(darkList);
-    pil_free(exposureTime);
+    cpl_free(darkList);
+    cpl_free(exposureTime);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
   }
@@ -1379,8 +1387,8 @@ vmdark(PilSetOfFrames *sof)
                 "method '%s'!", combMethodNames[combMethodEntry]);
     for (i = 0; i < goodFrames; i++)
       deleteImage(darkList[i]);
-    pil_free(darkList);
-    pil_free(exposureTime);
+    cpl_free(darkList);
+    cpl_free(exposureTime);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
   }
@@ -1393,7 +1401,7 @@ vmdark(PilSetOfFrames *sof)
   for (i = 0; i < goodFrames; i++)
     sumExposures += exposureTime[i];
 
-  pil_free(exposureTime);
+  cpl_free(exposureTime);
 
   if (!mDark) {
     cpl_msg_error(task, 
@@ -1529,7 +1537,7 @@ vmdark(PilSetOfFrames *sof)
       qcWriteValueDouble(mDark->descs, medianValue, "QC.DARK.MASTER.MEDIAN", 
                          "ADU/s", "Median master dark level");
 
-      pil_free(sample);
+      cpl_free(sample);
 
       /* QC.DARK.CURRENT */
 
@@ -1558,7 +1566,7 @@ vmdark(PilSetOfFrames *sof)
 
   for (i = 0; i < goodFrames; i++)
     deleteImage(darkList[i]);
-  pil_free(darkList);
+  cpl_free(darkList);
 
 
  /*
@@ -1633,7 +1641,7 @@ vmdark(PilSetOfFrames *sof)
    * update the set of frames.
    */
 
-  strlower(strcpy(masterDarkName, mdarkTag));
+  vmstrlower(strcpy(masterDarkName, mdarkTag));
   strcat(masterDarkName, ".fits");
 
   if (createFitsImage(masterDarkName, mDark, mdarkTag)) {
