@@ -30,7 +30,11 @@
 
 #include <cpl.h>
 
+CPL_BEGIN_DECLS
+
 double fors_get_airmass(const cpl_propertylist *header);
 double fors_tools_get_kth_double(double *, int , int );
 
+CPL_END_DECLS
+
 #endif
