@@ -72,9 +72,9 @@ cpl_propertylist * vimos_calib_flat_qc(mosca::image& master_flat,
                                       double alltime, double xwidth,
                                       double ywidth, double gain, 
                                       double focu_scale,
-									  double resolution,
-									  int nwaves,
-									  double accuracy);
+                                                                          double resolution,
+                                                                          int nwaves,
+                                                                          double accuracy);
 
 
 
@@ -491,6 +491,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     if (mos > 1)
         vimos_calib_exit("Just one input arc lamp frame is allowed"); 
 
+
     arc_tag                  = "MOS_ARC_SPECTRUM";
     flat_tag                 = "MOS_SCREEN_FLAT";
     master_screen_flat_tag   = "MOS_COMBINED_SCREEN_FLAT";
@@ -545,6 +546,9 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     if (master_bias == NULL || master_bias_err == NULL || master_bias_header == NULL)
         vimos_calib_exit("Cannot load master bias");
 
+   /* cpl_image_delete(master_bias_err);*/
+
+
     /*
      * Load flats
      */
@@ -584,6 +588,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
         cpl_propertylist_delete(header); header = NULL;
 
     }
+    
 
     /*
      * Compute tracing master flat
@@ -591,47 +596,86 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     cpl_frameset * frameset_copy = cpl_frameset_duplicate(frameset);
     cpl_image * master_flat_raw = 
             dfs_load_image(frameset, flat_tag, CPL_TYPE_FLOAT, 0, 0);
+
+
     cpl_propertylist * master_flat_header = 
             dfs_load_header(frameset_copy, flat_tag, 0);
-    //Subtract prescan
+
+   
+    /*Subtract prescan*/
     cpl_image * master_flat_var = 
         vimos_image_variance_from_detmodel(master_flat_raw, 
                 master_flat_header, master_bias_header);
+
     if(cpl_error_get_code() != CPL_ERROR_NONE)
         throw std::invalid_argument("Could not get RON from master bias"
             " (missing QC DET OUT? RON keywords)");
-    cpl_image * master_flat_notrim = 
+
+    cpl_image * master_flat_notrim = NULL;
+    master_flat_notrim = 
          vimos_subtract_overscan(master_flat_raw, master_flat_var, master_flat_header);
+
+
+    cpl_image_delete(master_flat_raw);
+    cpl_image_delete(master_flat_var);
+
+
+    
     //Trimm flat
+    master_flat=NULL;
     master_flat = vimos_trimm_preoverscan(master_flat_notrim, master_flat_header);
+    cpl_image_delete(master_flat_notrim);
+    cpl_propertylist_delete(master_flat_header);
+
     //Subtract master bias
     cpl_image_subtract(master_flat, master_bias);
 
     if (master_flat == NULL)
         vimos_calib_exit("Cannot load flat field");
 
+
+
     for (i = 1; i < nflats; i++) {
+    
         cpl_image * flat_raw =
                 dfs_load_image(frameset, NULL, CPL_TYPE_FLOAT, 0, 0);
+
+
         //Subtract prescan
         cpl_propertylist * flat_header = 
                 dfs_load_header(frameset_copy, NULL, 0);
+        
         cpl_image * flat_var = 
             vimos_image_variance_from_detmodel(flat_raw, 
                     flat_header, master_bias_header);
+        
         cpl_image * flat_notrim = 
              vimos_subtract_overscan(flat_raw, flat_var, flat_header);
+        
+        cpl_image_delete(flat_var);
+        cpl_image_delete(flat_raw);
+        
         //Trimm flat
         flat = vimos_trimm_preoverscan(flat_notrim, flat_header);
+        
+        cpl_image_delete(flat_notrim);
+        cpl_propertylist_delete(flat_header);
+        
         //Subtract master bias
         cpl_image_subtract(flat, master_bias);
         if (flat) {
             cpl_image_add(master_flat, flat);
             cpl_image_delete(flat); flat = NULL;
-        }
-        else
+        } else {
             vimos_calib_exit("Cannot load flat field");
+        }
+    
     }
+    
+    /* Free up the temporary frameset copy */
+    cpl_frameset_delete(frameset_copy);
+
+
 
     /*
      * Get some info from arc lamp header
@@ -645,7 +689,6 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     instrume = cpl_propertylist_get_string(arc_header, "INSTRUME");
     if (instrume == NULL)
         vimos_calib_exit("Missing keyword INSTRUME in arc lamp header");
-    instrume = cpl_strdup(instrume);
 
     arctime = cpl_propertylist_get_double(arc_header, "EXPTIME");
 
@@ -778,9 +821,15 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     cpl_msg_info(recipe, "Subtract pre/overscan..");
     cpl_image * spectra_notrimm =
             vimos_subtract_overscan(spectra_raw, spectra_var, arc_header);
-    //Trimm arc
+    cpl_image_delete(spectra_raw);
+            
+    /*
+     * Trimm arc
+    */
     spectra = vimos_trimm_preoverscan(spectra_notrimm, arc_header);
-    
+    cpl_image_delete(spectra_notrimm);
+    cpl_image_delete(spectra_var);
+
     cpl_msg_info(recipe, "Remove the master bias...");
 
     if (cpl_image_subtract(spectra, master_bias))
@@ -809,6 +858,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     ccd_xsize = nx = cpl_image_get_size_x(spectra);      // added...
     ccd_ysize = ny = cpl_image_get_size_y(spectra);
 
+
     if (treat_as_lss) {
 
         /*
@@ -829,11 +879,11 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
         idscoeff = cpl_table_new(ny);
         refmask  = cpl_mask_new(nx, ny);
 
-	if (mos_saturation_process(spectra))
-	    vimos_calib_exit("Cannot process saturation");
+        if (mos_saturation_process(spectra))
+            vimos_calib_exit("Cannot process saturation");
 
-	if (mos_subtract_background(spectra))
-	    vimos_calib_exit("Cannot subtract the background");
+        if (mos_subtract_background(spectra))
+            vimos_calib_exit("Cannot subtract the background");
 
         rectified = mos_wavelength_calibration_raw(spectra, lines, dispersion,
                                                    peakdetection, wradius,
@@ -918,10 +968,10 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
         refmask = cpl_mask_new(nx, ny);
 
         if (mos_saturation_process(spectra))
-	    vimos_calib_exit("Cannot process saturation");
+            vimos_calib_exit("Cannot process saturation");
 
         if (mos_subtract_background(spectra))
-	    vimos_calib_exit("Cannot subtract the background");
+            vimos_calib_exit("Cannot subtract the background");
 
         // Begin code to smooth image
 
@@ -938,6 +988,9 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
 
         // End code to smooth image
 
+
+/*MNB NO LEAKS UP TILL HERE */
+
         checkwave = mos_wavelength_calibration_raw(spectra, lines, dispersion, 
                                                    peakdetection, wradius, 
                                                    wdegree, wreject, reference,
@@ -948,6 +1001,11 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
                                                    disp_tolerance,
                                                    ratio_tolerance);
 
+
+/*MNB LEAK MARKER (55):  LEAKS FROM BETWEEN HERE */
+
+
+
         if (checkwave == NULL)
             vimos_calib_exit("Wavelength calibration failure.");
 
@@ -1001,6 +1059,11 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
 
     cpl_image_delete(refimage); refimage = NULL;
 
+
+/* MNB LEAK MARKER (55) : TO HERE  */
+
+
+
     if (slit_ident && !treat_as_lss) {
 
         /*
@@ -1344,7 +1407,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
 
     if (restab) {
         cpl_msg_info(recipe, "Mean spectral resolution: %.2f",
-        		cpl_table_get_column_mean(restab, "resolution"));
+                        cpl_table_get_column_mean(restab, "resolution"));
         cpl_msg_info(recipe, "Mean reference lines FWHM: %.2f +/- %.2f pixel",
                    cpl_table_get_column_mean(restab, "fwhm") / dispersion,
                    cpl_table_get_column_mean(restab, "fwhm_rms") / dispersion);
@@ -1889,12 +1952,14 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     
     std::unique_ptr<mosca::image> master_flat_d;
     std::auto_ptr<mosca::fiera_config> ccd_config;
+
     master_flat_d = vimos_calib_flat_mos_create_master_flat(calib_slits,
             wave_cal, *grism_cfg, master_bias, master_bias_err,
             master_bias_header, frameset, flat_tag);
     if(master_flat_d.get() == 0 || cpl_error_get_code() != CPL_ERROR_NONE)
         vimos_calib_exit("Cannot combine flat frames");
 
+
     /*
      * Perform Flat field normalisation
      */
@@ -2074,6 +2139,40 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     }
     cpl_propertylist_delete(header); header = NULL;
     cpl_table_delete(idscoeff); idscoeff = NULL;
+    
+    cpl_free(grism);
+    cpl_free(fiterror);                           \
+    cpl_free(fitlines);                    
+    cpl_image_delete(master_bias);         
+    cpl_image_delete(master_bias_err);         
+    cpl_image_delete(coordinate);          
+    cpl_image_delete(checkwave);           
+    cpl_image_delete(flat);                
+    cpl_image_delete(master_flat);         
+    cpl_image_delete(rainbow);             
+    cpl_image_delete(rectified);           
+    cpl_image_delete(residual);            
+    cpl_image_delete(smo_flat);            
+    cpl_image_delete(spatial);             
+    cpl_image_delete(spectra);             
+    cpl_image_delete(wavemap);             
+    cpl_image_delete(delta);               
+    cpl_mask_delete(refmask);              
+    cpl_propertylist_delete(header);       
+    cpl_propertylist_delete(save_header);  
+    cpl_propertylist_delete(qclist);       
+    cpl_table_delete(grism_table);         
+    cpl_table_delete(idscoeff);            
+    cpl_table_delete(restable);            
+    cpl_table_delete(maskslits);           
+    cpl_table_delete(traces);              
+    cpl_table_delete(polytraces);          
+    cpl_table_delete(slits);               
+    cpl_table_delete(restab);              
+    cpl_table_delete(global);              
+    cpl_vector_delete(lines);              
+    cpl_msg_indent_less();                 
+
 
     return 0;
 }
@@ -2253,9 +2352,9 @@ cpl_propertylist * vimos_calib_flat_qc(mosca::image& master_flat,
                                       double alltime, double xwidth,
                                       double ywidth, double gain, 
                                       double focu_scale,
-									  double qc_resolution,
-									  int qc_nwaves,
-									  double qc_accuracy_nm)
+                                                                          double qc_resolution,
+                                                                          int qc_nwaves,
+                                                                          double qc_accuracy_nm)
 {
     double     slit_width;
     double     flux, flux_err;
@@ -2285,11 +2384,11 @@ cpl_propertylist * vimos_calib_flat_qc(mosca::image& master_flat,
                                    "ESO PRO WLEN END", grism_cfg.end_wave());
 
     cpl_propertylist_update_double(qc_list,
-    							idp_input_screen_flat_resolution, qc_resolution);
+                                                            idp_input_screen_flat_resolution, qc_resolution);
     cpl_propertylist_update_int(qc_list,
-    							idp_input_screen_flat_nwave, qc_nwaves);
+                                                            idp_input_screen_flat_nwave, qc_nwaves);
     cpl_propertylist_update_double(qc_list,
-    							idp_input_screen_flat_accuracy, qc_accuracy_nm);
+                                                            idp_input_screen_flat_accuracy, qc_accuracy_nm);
 
     /*
      * QC1 parameters
