@@ -48,8 +48,9 @@
 #include "vimos_detmodel.h"
 #include "vimos_flat_normalise.h"
 #include "flat_combine.h"
+#include "vimos_spec_idp.h"
 
-std::auto_ptr<mosca::image> vimos_calmul_flat_mos_create_master_flat
+std::unique_ptr<mosca::image> vimos_calmul_flat_mos_create_master_flat
 (vimos::calibrated_slits& calibrated_slits, 
  const mosca::wavelength_calibration& wave_cal,
  const mosca::grism_config& grism_cfg,
@@ -59,19 +60,23 @@ std::auto_ptr<mosca::image> vimos_calmul_flat_mos_create_master_flat
  const char * flat_tag);
 
 int vimos_calmul_flats_save
-(std::auto_ptr<mosca::image>& master_flat_d, 
- std::auto_ptr<mosca::image>& norm_flat,
+(mosca::image& master_flat_d, 
+ std::unique_ptr<mosca::image>& norm_flat,
  cpl_frameset * frameset, const char * flat_tag, 
  const char * master_screen_flat_tag, const char * master_norm_flat_tag, 
  cpl_parameterlist * parlist, cpl_propertylist * qc_list, int i);
 
+static
 cpl_propertylist * vimos_calmul_flat_qc(mosca::image& master_flat, 
                                       cpl_table * slits,
                                       int nx, int ny, int nflats,
                                       mosca::grism_config& grism_cfg,
                                       double alltime, double xwidth,
                                       double ywidth, double gain, 
-                                      double focu_scale);
+                                      double focu_scale,
+									  double qc_resolution,
+									  int qc_nwaves,
+									  double qc_accuracy_nm);
 
 #define vimos_calmul_exit(message)            \
 {                                             \
@@ -491,8 +496,12 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
     ratio_tolerance = dfs_get_parameter_double(parlist, 
             "vimos.vmmoscalib.line_ident_tol", NULL);
     
-    disp_tolerance = 0.2; 
-            
+
+    disp_tolerance = 0.2;
+
+    const bool normalise_spa_local = dfs_get_parameter_bool(parlist,
+                    "vimos.vmmoscalib.normalise_spa_local", NULL);
+
     if (cpl_error_get_code())
         vimos_calmul_exit("Failure getting the configuration parameters");
 
@@ -866,7 +875,9 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
                     vimos_calmul_exit(NULL);
                 }
             }
-            if (dfs_save_image_ext(checkwave, spectra_detection_tag, header)) {
+            std::stringstream ss;
+            ss<<"DATA."<<(i + 1);
+            if (dfs_save_image_ext_name(checkwave, spectra_detection_tag, header, ss.str().c_str())) {
                 vimos_calmul_exit(NULL);
             }
             cpl_propertylist_delete(header); header = NULL;
@@ -929,6 +940,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
     if (slit_ident) {
 
         /*
+         * Slit identification is forced to TRUE in case of multiplexing.
          * Slit identification: this recipe may continue even
          * in case of failed identification (i.e., the position table is 
          * not produced, but an error is not set). In case of failure,
@@ -1051,7 +1063,9 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
             }
         }
 
-        if (dfs_save_table_ext(traces, curv_traces_tag, NULL)) {
+        std::stringstream ss;
+        ss<<"DATA."<<(i + 1);
+        if (dfs_save_table_ext_name(traces, curv_traces_tag, NULL, ss.str().c_str())) {
             vimos_calmul_exit(NULL);
         }
 
@@ -1213,10 +1227,10 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
             }
         }
 
-        if (dfs_save_table_ext(restable, disp_residuals_table_tag, NULL)) 
+        if (dfs_save_table_ext_name(restable, disp_residuals_table_tag, NULL, ss.str().c_str()))
             vimos_calmul_exit(NULL);
 
-        if (dfs_save_table_ext(detected_lines, detected_lines_tag, NULL))
+        if (dfs_save_table_ext_name(detected_lines, detected_lines_tag, NULL, ss.str().c_str()))
             vimos_calmul_exit(NULL);
 
         cpl_table_delete(detected_lines); detected_lines = NULL;
@@ -1272,7 +1286,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
             }
         }
 
-        if (dfs_save_image_ext(delta, delta_image_tag, header)) {
+        if (dfs_save_image_ext_name(delta, delta_image_tag, header, ss.str().c_str())) {
             vimos_calmul_exit(NULL);
         }
 
@@ -1282,6 +1296,8 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
         mean_rms = mos_distortions_rms(rectified, lines, startwavelength, 
                                        dispersion, 6, 0);
 
+        const double accuracy_nm = mean_rms * dispersion / 10.0;
+
         cpl_msg_info(recipe, "Mean residual: %f pixel", mean_rms);
 
         mean_rms = cpl_table_get_column_mean(idscoeff, "error");
@@ -1308,7 +1324,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
                 }
             }
 
-            if (dfs_save_table_ext(restab, spectral_resolution_tag, NULL)) {
+            if (dfs_save_table_ext_name(restab, spectral_resolution_tag, NULL, ss.str().c_str())) {
                 vimos_calmul_exit(NULL);
             }
 
@@ -1318,6 +1334,11 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
         else
             vimos_calmul_exit("Cannot compute the spectral resolution table");
 
+
+        const double qc_resolution = cpl_table_get_column_mean(restab,
+                "resolution");
+        const int qc_nwaves = cpl_table_get_nrow(restab);
+
         cpl_propertylist * disp_coeff_header = cpl_propertylist_new();
         cpl_propertylist_update_double(disp_coeff_header,
                                        "ESO PRO WLEN CEN", reference);
@@ -1335,7 +1356,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
             }
         }
 
-        if (dfs_save_table_ext(idscoeff, disp_coeff_tag, NULL)) {
+        if (dfs_save_table_ext_name(idscoeff, disp_coeff_tag, NULL, ss.str().c_str())) {
             vimos_calmul_exit(NULL);
         }
         cpl_propertylist_delete(disp_coeff_header);
@@ -1739,8 +1760,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
                 vimos_calmul_exit(NULL);
             }
         }
-
-        if (dfs_save_image_ext(rectified, reduced_lamp_tag, header)) {
+        if (dfs_save_image_ext_name(rectified, reduced_lamp_tag, header, ss.str().c_str())) {
             vimos_calmul_exit(NULL);
         }
 
@@ -1755,7 +1775,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
                 }
             }
 
-            if (dfs_save_image_ext(residual, disp_residuals_tag, NULL)) {
+            if (dfs_save_image_ext_name(residual, disp_residuals_tag, NULL, ss.str().c_str())) {
                 vimos_calmul_exit(NULL);
             }
 
@@ -1801,7 +1821,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
         cpl_msg_indent_less();
         cpl_msg_info(recipe, "Perform flat field combination...");
         
-        std::auto_ptr<mosca::image> master_flat_d;
+        std::unique_ptr<mosca::image> master_flat_d;
         std::auto_ptr<mosca::fiera_config> ccd_config;
         master_flat_d = vimos_calmul_flat_mos_create_master_flat(calib_slits,
                 wave_cal, *grism_cfg, master_bias, master_bias_err,
@@ -1815,7 +1835,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
         
         cpl_msg_info(recipe, "Perform flat field normalisation...");
         
-        std::auto_ptr<mosca::image> norm_flat;
+        std::unique_ptr<mosca::image> norm_flat;
         norm_flat.reset(new mosca::image(cpl_image_cast(master_flat_d->get_cpl_image(), 
                                                         CPL_TYPE_FLOAT),
                                          cpl_image_cast(master_flat_d->get_cpl_image_err(), 
@@ -1826,16 +1846,18 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
                                  coordinate, calib_slits, subslits, polytraces,
                                  startwavelength, endwavelength,
                                  dispersion, sradius, dradius,
-                                 spa_polyorder, disp_nknots, fit_threshold);
+                                 spa_polyorder, disp_nknots, fit_threshold,
+                                 normalise_spa_local);
         if( cpl_error_get_code() != CPL_ERROR_NONE)
             vimos_calmul_exit("Cannot normalize master flat");
 
         //Saving the flats
         cpl_propertylist * qc_list = vimos_calmul_flat_qc(*master_flat_d,
                  subslits, nx, ny, nflats, *grism_cfg, alltime, xwidth, ywidth, 
-                 gain, scale);
+                 gain, scale, qc_resolution, qc_nwaves, accuracy_nm);
+
         //cpl_propertylist * qc_list = cpl_propertylist_new();
-        vimos_calmul_flats_save(master_flat_d,  norm_flat, frameset, flat_tag, 
+        vimos_calmul_flats_save(*master_flat_d,  norm_flat, frameset, flat_tag, 
                                master_screen_flat_tag, master_norm_flat_tag, 
                                parlist, qc_list, i);
 
@@ -1890,8 +1912,8 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
                 vimos_calmul_exit(NULL);
             }
         }
-        if (dfs_save_image_ext(wave_profiles, flat_sed_tag,
-                              sed_header))
+        if (dfs_save_image_ext_name(wave_profiles, flat_sed_tag,
+                              sed_header, ss.str().c_str()))
             vimos_calmul_exit(NULL);
 
         
@@ -1911,7 +1933,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
             }
         }
 
-        if (dfs_save_image_ext(wavemap, wavelength_map_tag, NULL)) {
+        if (dfs_save_image_ext_name(wavemap, wavelength_map_tag, NULL, ss.str().c_str())) {
             vimos_calmul_exit(NULL);
         }
 
@@ -1926,7 +1948,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
             }
         }
 
-        if (dfs_save_image_ext(coordinate, spatial_map_tag, NULL)) {
+        if (dfs_save_image_ext_name(coordinate, spatial_map_tag, NULL, ss.str().c_str())) {
             vimos_calmul_exit(NULL);
         }
 
@@ -1940,7 +1962,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
             }
         }
 
-        if (dfs_save_table_ext(polytraces, curv_coeff_tag, NULL)) {
+        if (dfs_save_table_ext_name(polytraces, curv_coeff_tag, NULL, ss.str().c_str())) {
             vimos_calmul_exit(NULL);
         }
         
@@ -1954,7 +1976,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
             }
         }
 
-        if (dfs_save_table_ext(subslits, slit_location_tag, NULL)) {
+        if (dfs_save_table_ext_name(subslits, slit_location_tag, NULL, ss.str().c_str())) {
             vimos_calmul_exit(NULL);
         }
 
@@ -2261,6 +2283,8 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
         for (i = 1; i <= ngroups; i++) {
             cpl_image *image = cpl_image_load(tmpname, CPL_TYPE_FLOAT, 0, i);
             header = cpl_propertylist_load(tmpname, i);
+            std::stringstream ss; ss<<"DATA."<<i;
+            cpl_propertylist_update_string(header, "EXTNAME", ss.str().c_str());
             cpl_image_save(image, name, CPL_BPP_IEEE_FLOAT,
                            header, CPL_IO_EXTEND);
             cpl_image_delete(image);
@@ -2279,7 +2303,7 @@ int vimos_calib_mult(cpl_frameset *frameset, cpl_parameterlist *parlist,
     return 0;
 }
 
-std::auto_ptr<mosca::image> vimos_calmul_flat_mos_create_master_flat
+std::unique_ptr<mosca::image> vimos_calmul_flat_mos_create_master_flat
 (vimos::calibrated_slits& calibrated_slits, 
  const mosca::wavelength_calibration& wave_cal,
  const mosca::grism_config& grism_cfg,
@@ -2290,7 +2314,7 @@ std::auto_ptr<mosca::image> vimos_calmul_flat_mos_create_master_flat
 {
     const char     * recipe_name = "fors_calib";
     cpl_errorstate   error_prevstate = cpl_errorstate_get();
-    std::auto_ptr<mosca::image> master_flat;
+    std::unique_ptr<mosca::image> master_flat;
 
     cpl_msg_indent_more();
 
@@ -2388,8 +2412,8 @@ std::auto_ptr<mosca::image> vimos_calmul_flat_mos_create_master_flat
 }
 
 int vimos_calmul_flats_save
-(std::auto_ptr<mosca::image>& master_flat_d, 
- std::auto_ptr<mosca::image>& norm_flat,
+(mosca::image& master_flat_d, 
+ std::unique_ptr<mosca::image>& norm_flat,
  cpl_frameset * frameset, const char * flat_tag, 
  const char * master_screen_flat_tag, const char * master_norm_flat_tag, 
  cpl_parameterlist * parlist, cpl_propertylist * qc_list, int i)
@@ -2401,18 +2425,22 @@ int vimos_calmul_flats_save
     cpl_msg_indent_more();
 
     /* Saving regular flat */
-    cpl_image_turn(master_flat_d->get_cpl_image(), -1);
-    cpl_image_turn(master_flat_d->get_cpl_image_err(), -1);
+    cpl_image_turn(master_flat_d.get_cpl_image(), -1);
+    cpl_image_turn(master_flat_d.get_cpl_image_err(), -1);
     if (i == 0) {
         if (dfs_save_image_null(frameset, NULL, parlist, master_screen_flat_tag,
                 recipe_name, version)) {
             return(-1);
         }
     }
-    dfs_save_image_ext(master_flat_d->get_cpl_image(), 
-                   master_screen_flat_tag, qc_list);
-    dfs_save_image_ext(master_flat_d->get_cpl_image_err(), 
-                       master_screen_flat_tag, qc_list);
+
+    std::stringstream ss_d, ss_e;
+    ss_d<<"DATA."<<(i + 1);
+    ss_e<<"ERROR."<<(i + 1);
+    dfs_save_image_ext_name(master_flat_d.get_cpl_image(),
+                   master_screen_flat_tag, qc_list, ss_d.str().c_str());
+    dfs_save_image_ext_name(master_flat_d.get_cpl_image_err(),
+                       master_screen_flat_tag, qc_list, ss_e.str().c_str());
 
     if(cpl_error_get_code() != CPL_ERROR_NONE)
         return -1;
@@ -2428,10 +2456,10 @@ int vimos_calmul_flats_save
                 return(-1);
             }
         }
-        dfs_save_image_ext(norm_flat->get_cpl_image(), 
-                       master_norm_flat_tag, qc_list);
-        dfs_save_image_ext(norm_flat->get_cpl_image_err(), 
-                           master_norm_flat_tag, NULL);
+        dfs_save_image_ext_name(norm_flat->get_cpl_image(),
+                       master_norm_flat_tag, qc_list, ss_d.str().c_str());
+        dfs_save_image_ext_name(norm_flat->get_cpl_image_err(),
+                           master_norm_flat_tag, NULL, ss_e.str().c_str());
         if(cpl_error_get_code() != CPL_ERROR_NONE)
             return -1;
     }
@@ -2449,7 +2477,10 @@ cpl_propertylist * vimos_calmul_flat_qc(mosca::image& master_flat,
                                       mosca::grism_config& grism_cfg,
                                       double alltime, double xwidth,
                                       double ywidth, double gain, 
-                                      double focu_scale)
+                                      double focu_scale,
+									  double qc_resolution,
+									  int qc_nwaves,
+									  double qc_accuracy_nm)
 {
     double     slit_width;
     double     flux, flux_err;
@@ -2478,7 +2509,12 @@ cpl_propertylist * vimos_calmul_flat_qc(mosca::image& master_flat,
     cpl_propertylist_update_double(qc_list,
                                    "ESO PRO WLEN END", grism_cfg.end_wave());
 
-
+    cpl_propertylist_update_double(qc_list,
+    							idp_input_screen_flat_resolution, qc_resolution);
+    cpl_propertylist_update_int(qc_list,
+    							idp_input_screen_flat_nwave, qc_nwaves);
+    cpl_propertylist_update_double(qc_list,
+    							idp_input_screen_flat_accuracy, qc_accuracy_nm);
     /*
      * QC1 parameters
      */
