@@ -1,7 +1,7 @@
-/* $Id: fors_dfs.c,v 1.6 2013-07-11 11:22:27 cgarcia Exp $
+/* $Id: vimos_dfs.c,v 1.14 2015/11/16 12:40:45 jim Exp $
  *
- * This file is part of the FORS library
- * Copyright (C) 2002-2006 European Southern Observatory
+ * This file is part of the VIMOS Pipeline
+ * Copyright (C) 2015 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,44 +15,65 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 /*
- * $Author: cgarcia $
- * $Date: 2013-07-11 11:22:27 $
- * $Revision: 1.6 $
- * $Name: not supported by cvs2svn $
+ * $Author: jim $
+ * $Date: 2015/11/16 12:40:45 $
+ * $Revision: 1.14 $
+ * $Name:  $
  */
 
+
+/* Includes */
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <vimos_dfs.h>
-
-#include <cpl.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <stdbool.h>
 #include <string.h>
 #include <unistd.h>
+#include <cpl.h>
+
+#include "vimos_dfs.h"
+#include "vimos_imaging_utils.h"
+#include "casu_utils.h"
+
+#define PACKSZ 1024
+#define DELEXTN "^(ESO.INS |ESO.OBS |ESO.TEL |INSTRUME|PIPEFILE|ORIGIN" \
+                "|TELESCOP|OBJECT|RA|DEC|INHERIT|EQUINOX|DATAMD5|RADECSYS" \
+                "|DATE-OBS|MJD-OBS|UTC|LST|PI-COI|OBSERVER|ORIGIN|DATE" \
+                "|ESO.TPL |ESO.DPR |ESO.ADA |HISTORY|ZSIMPLE|ZHECKSUM" \
+                "|ZDATASUM|ESO.PRO.CATG|ESO.PRO.TYPE|ESO.PRO.TECH" \
+                "|ESO.PRO.SCIENCE).*$"
+#define DELPRIMARY "^(CRVAL|CRPIX|CTYPE|CD|ESO.DET |ESO.DRS " \
+                   "|ESO.OCS |EXTNAME|HISTORY|ZSIMPLE" \
+                   "|ZHECKSUM|ZDATASUM).*$"
+
+#define REGFIX "^(ORIGIN|TELESCOP|INSTRUME|OBJECT|RA|DEC|EPOCH|EQUINOX" \
+    "|RADECSYS|DATE-OBS|MJD-OBS|UTC|LST|PI-COI|OBSERVER)$"
+#define WCS_KEYS "^((CRVAL|CRPIX|CTYPE|CDELT)[0-9]|RADECSYS|CD[0-9]_[0-9])$"
 
-/*----------------------------------------------------------------------------*/
 /**
- * @defgroup vimosdfs DFS Utilities
- *
- *   The module vimos_dfs collects medium level functions related to 
- *   DFS data IO.
- */
-/*----------------------------------------------------------------------------*/
+   \defgroup vimos_dfs vimos_dfs
+   \ingroup supportroutines
+
+   \brief
+   The module vimos_dfs collects medium level functions related to 
+   DFS data IO.
+
+   \author
+   Jim Lewis, CASU
+
+*/
 
 /**@{*/
 
-#define WCS_KEYS "^((CRVAL|CRPIX|CTYPE|CDELT)[0-9]|RADECSYS|CD[0-9]_[0-9])$"
-
 /*------------------------------------------------------------------------------
     Prototypes
  -----------------------------------------------------------------------------*/
@@ -63,8 +84,240 @@ errorstate_dump_one(unsigned self, unsigned first, unsigned last);
     Implementation
  -----------------------------------------------------------------------------*/
 
-/*----------------------------------------------------------------------------*/
-/*----------------------------------------------------------------------------*/
+/*---------------------------------------------------------------------------*/
+/**
+    \par Name:
+        vimos_dfs_set_groups
+    \par Purpose:
+        Set the group of each frame in a frameset as RAW or CALIB according
+        to DO.CATG tag given to it.
+    \par Description:
+        A frameset is given. Each frame in the frameset is classified as
+        RAW or CALIB depending upon the dfs tag it's been given.
+    \par Language:
+        C
+    \param set     
+        The input frameset
+    \retval CASU_OK 
+        If everything is ok
+    \retval CASU_FATAL 
+        If NULL frameset
+    \author
+        Jim Lewis, CASU
+
+ */
+/*---------------------------------------------------------------------------*/
+
+int vimos_dfs_set_groups(cpl_frameset *set) {
+    cpl_frame *cur_frame;
+    const char *tag;
+    const char *fctid = "vimos_dfs_set_groups";
+    int nframes,i;
+
+    /* Check entries */
+
+    if (set == NULL) 
+        return(CASU_FATAL); 
+    
+    /* Initialize */
+
+    nframes = cpl_frameset_get_size(set);
+
+    /* Loop on frames */
+
+    for (i = 0; i < nframes; i++) {
+        cur_frame = cpl_frameset_get_position(set,i);
+        tag = cpl_frame_get_tag(cur_frame);
+       
+        /* RAW frames */
+
+        if (!strcmp(tag,VIMOS_BIAS_RAW)  ||
+            !strcmp(tag,VIMOS_TWI_RAW)   ||
+            !strcmp(tag,VIMOS_DARK_RAW)  ||
+            !strcmp(tag,VIMOS_STD_OBJECT_RAW) ||
+            !strcmp(tag,VIMOS_SCI_OBJECT_RAW))
+            cpl_frame_set_group(cur_frame,CPL_FRAME_GROUP_RAW);
+
+        /* CALIB frames */
+
+        else if (!strcmp(tag,VIMOS_CAL_BIAS) ||
+                 !strcmp(tag,VIMOS_CAL_DARK) ||
+                 !strcmp(tag,VIMOS_CAL_TWILIGHT_FLAT) ||
+                 !strcmp(tag,VIMOS_CAL_CONF) ||
+                 !strcmp(tag,VIMOS_CAL_FRINGE) ||
+                 !strcmp(tag,VIMOS_CAL_FRINGE_VAR) ||
+                 !strcmp(tag,VIMOS_CAL_READGAIN) ||
+                 !strcmp(tag,VIMOS_CAL_BPM) ||
+                 !strcmp(tag,VIMOS_CAL_PHOTTAB) ||
+                 !strcmp(tag,VIMOS_CAL_2MASS_A) ||
+                 !strcmp(tag,VIMOS_CAL_PPMXL_A) ||
+                 !strcmp(tag,VIMOS_CAL_APASS_A) ||
+                 !strcmp(tag,VIMOS_CAL_LOCCAT_A) ||
+                 !strcmp(tag,VIMOS_CAL_APASS_P) ||
+                 !strcmp(tag,VIMOS_CAL_LOCCAT_P) ||
+                 !strcmp(tag,VIMOS_CAL_SCHL_N) ||
+                 !strcmp(tag,VIMOS_CAL_SCHL_S) ||
+                 !strcmp(tag,VIMOS_CAL_MSTD_PHOT) ||
+                 !strcmp(tag,VIMOS_CAL_STDSTAR) || 
+                 !strcmp(tag,VIMOS_REF_BIAS) ||
+                 !strcmp(tag,VIMOS_REF_DARK) ||
+                 !strcmp(tag,VIMOS_REF_BPM) ||
+                 !strcmp(tag,VIMOS_REF_CONF) ||
+                 !strcmp(tag,VIMOS_REF_TWILIGHT_FLAT))
+            cpl_frame_set_group(cur_frame,CPL_FRAME_GROUP_CALIB);
+        else 
+            cpl_msg_info(fctid,"No such tag as %s in frame %s",tag,
+                         cpl_frame_get_filename(cur_frame));
+    }
+    return(CASU_OK);
+}
+
+/*---------------------------------------------------------------------------*/
+/**
+    \par Name:
+        vimos_dfs_set_product_primary_header
+    \par Purpose:
+        Set the dfs product header keywords in the primary header
+    \par Description:
+        Set the dfs product header keywords in the primary header
+    \par Language:
+        C
+    \param plist     
+        The propertylist to which the keywords should be appended
+    \param frame
+        The output product frame
+    \param frameset
+        The input recipe frameset
+    \param parlist
+        The parameter list of the input recipe
+    \param recipeid
+        The name of the input recipe
+    \param dict
+        The dictionary ID
+    \param inherit
+        The frame from which you want to inherit useful header information
+    \param synch
+        If set, then the timing information that has been added by the
+        relevant cpl_ routine can be overwritten by the timing information
+        from the original propertylist
+    \author
+        Jim Lewis, CASU
+ */
+/*---------------------------------------------------------------------------*/
+
+void vimos_dfs_set_product_primary_header(cpl_propertylist *plist,
+                                          cpl_frame *frame,
+                                          cpl_frameset *frameset,
+                                          cpl_parameterlist *parlist,
+                                          const char *recipeid, 
+                                          const char *dict,
+                                          cpl_frame *inherit,
+                                          int synch) {
+    const char *fctid="vimos_dfs_set_product_primary_header";
+    char package[PACKSZ];
+    cpl_propertylist *pcopy;
+
+    /* Get the package name and version */
+
+    (void)snprintf(package,PACKSZ,"%s/%s",PACKAGE,PACKAGE_VERSION);
+
+    /* Make a copy of the input propertylist so that we can restore the 
+       time and position dependent headers back to the way they were before
+       cpl_dfs_setup_product_header worked on it. */
+
+    pcopy = cpl_propertylist_duplicate(plist);
+
+    /* Add the data-flow keywords */
+
+    if (cpl_dfs_setup_product_header(plist,frame,frameset,parlist,recipeid,
+                                     package,dict,inherit) != CPL_ERROR_NONE) {
+        cpl_msg_warning(fctid,
+                        "Problem with the product primary DFS compliance -- %s",
+                        cpl_error_get_message());
+        cpl_error_reset();
+    }
+
+    /* Now fix the time/position information back to the way it was */
+
+    if (synch) 
+        cpl_propertylist_copy_property_regexp(plist,
+                                              (const cpl_propertylist *)pcopy,
+                                              REGFIX,0);
+
+    /* Remove the stuff that isn't supposed to be here */
+
+    cpl_propertylist_erase_regexp(plist,DELPRIMARY,0);
+    cpl_propertylist_delete(pcopy);
+
+    /* Add the software version */
+
+    cpl_propertylist_update_string(plist,"PROCSOFT",PACKAGE_VERSION);
+}
+
+/*---------------------------------------------------------------------------*/
+/**
+    \par Name:
+        vimos_dfs_set_product_exten_header
+    \par Purpose:
+        Set the dfs product header keywords in the primary header
+    \par Description:
+        Set the dfs product header keywords in the primary header
+    \par Language:
+        C
+    \param plist     
+        The propertylist to which the keywords should be appended
+    \param frame
+        The output product frame
+    \param frameset
+        The input recipe frameset
+    \param parlist
+        The parameter list of the input recipe
+    \param recipeid
+        The name of the input recipe
+    \param dict
+        The dictionary ID
+    \param inherit
+        The frame from which you want to inherit all the useful header info
+    \author
+        Jim Lewis, CASU
+ */
+/*---------------------------------------------------------------------------*/
+
+void vimos_dfs_set_product_exten_header(cpl_propertylist *plist,
+                                        cpl_frame *frame,
+                                        cpl_frameset *frameset,
+                                        cpl_parameterlist *parlist,
+                                        const char *recipeid, 
+                                        const char *dict,
+                                        cpl_frame *inherit) {
+    const char *fctid="vimos_dfs_set_product_exten_header";
+    char package[PACKSZ];
+    cpl_propertylist *rem;
+
+    /* Get the package name and version */
+
+    (void)snprintf(package,PACKSZ,"%s/%s",PACKAGE,PACKAGE_VERSION);
+
+    /* Add the data-flow keywords */
+
+    if (cpl_dfs_setup_product_header(plist,frame,frameset,parlist,recipeid,
+                                     package,dict,inherit) != CPL_ERROR_NONE) {
+        cpl_msg_warning(fctid,
+                        "Problem with the product extn DFS compliance -- %s",
+                        cpl_error_get_message());
+        cpl_error_reset();
+    }
+
+    /* Remove the stuff that isn't supposed to be here */
+
+    rem = cpl_propertylist_new();
+    cpl_propertylist_copy_property_regexp(rem,plist,"ESO.INS.FILT.*",0);
+    cpl_propertylist_erase_regexp(plist,DELEXTN,0);
+    cpl_propertylist_append(plist,rem);
+    cpl_propertylist_delete(rem);
+
+}
+
 char *vmstrlower(char *s)
 {
 
@@ -1371,39 +1624,6 @@ cpl_error_code dfs_save_image_null(cpl_frameset * frameset,
     return error;
 }
 
-void
-vimos_dfs_set_groups(cpl_frameset * set)
-{
-    cpl_frame *f;
-    int i, n;
-    
-    if(set == NULL)
-        return;
-    
-    n = cpl_frameset_get_size(set);
-    for (i = 0 ; i<n; i++)
-    {
-        f = cpl_frameset_get_position(set, i);
-
-        const char *tag = cpl_frame_get_tag(f);
-
-        if (tag != NULL) {
-            if (strcmp(tag, "BIAS") == 0 ) {
-                cpl_frame_set_group(f, CPL_FRAME_GROUP_RAW);
-            }
-            else if (strcmp(tag, "MASTER_BIAS") == 0) {
-                cpl_frame_set_group(f, CPL_FRAME_GROUP_CALIB);
-            }
-            else {
-                cpl_msg_warning(cpl_func, "Unrecognized frame tag: '%s'",
-                                tag);
-            }
-        }
-    }
-    
-    return;
-}
-
 /*----------------------------------------------------------------------------*/
 /** 
  * @brief  Extract frames with given tag from frameset
