@@ -54,7 +54,7 @@ public:
                       double dispersion,
                       int spa_smooth_radius, int disp_smooth_radius, 
                       int spa_fit_polyorder, int disp_fit_nknots,
-                      double fit_threshold);
+                      double fit_threshold, bool normalise_spa_local);
     
     const mosca::image& get_normalisation_image() const;
     
