@@ -283,11 +283,15 @@ std::vector<mosca::image> vimos_preoverscan::trimm_preoverscan
     return ima_list_trimmed;
 }
 
-void vimos_preoverscan::fix_wcs_trimm(cpl_propertylist * header)
-{
+mosca::rect_region vimos_preoverscan::get_wcs_crop_region(const cpl_propertylist * header){
     mosca::fiera_config ccd_config(header);
     mosca::rect_region crop_region = ccd_config.whole_valid_region();
-    mosca::rect_region crop_region_1 = crop_region.coord_0to1(); 
+    return crop_region.coord_0to1();
+}
+
+void vimos_preoverscan::fix_wcs_trimm(cpl_propertylist * header)
+{
+    mosca::rect_region crop_region_1 = get_wcs_crop_region(header);
     if(crop_region_1.is_empty())
         throw std::invalid_argument("Cannot fix WCS from overscan trimming");
     cpl_propertylist_update_double(header, "CRPIX1",
