@@ -45,7 +45,8 @@ cpl_table * vimos_compute_response
  const std::vector<double>& ignored_waves,
  const std::vector<std::pair<double, double> >& ignored_wave_ranges,
  int nknots, int degree, cpl_table *& response_interp,
- double& flat_sed_norm_factor)
+ double& flat_sed_norm_factor,
+ const vimos::detected_slits& det_slits)
 {
 
     cpl_image *spectrum       = NULL; // Extracted standard star spectrum
@@ -147,7 +148,7 @@ cpl_table * vimos_compute_response
                         cpl_image_get(spectrum_sedcorr, i_pix+1, 1, &null) / profile_val);
         }
         std::ostringstream norm_key;
-        norm_key<< "ESO QC FLAT SED"<<obj_slit+1<<" NORM";
+        norm_key<< "ESO QC FLAT SED_"<<det_slits[obj_slit].slit_id()<<" NORM";
         flat_sed_norm_factor = 
           cpl_propertylist_get_double(flat_sed_header, norm_key.str().c_str());
         if(cpl_error_get_code() == CPL_ERROR_DATA_NOT_FOUND)
@@ -324,56 +325,12 @@ cpl_table * vimos_compute_response
     return response_table;
 }
 
-cpl_image * vimos_science_map_disp_profile
-(cpl_frameset * frameset, const char * flat_sed_tag, 
- vimos::detected_slits& det_slits, mosca::wavelength_calibration& wave_cal,
- double firstLambda, double lastLambda, double dispersion, int section)
-{
-    const cpl_frame * flat_sed_frame = 
-            cpl_frameset_find_const(frameset, flat_sed_tag);
-    const char * filename = cpl_frame_get_filename(flat_sed_frame);
-
-    cpl_image * flat_sed = NULL;  
-    if (cpl_fits_count_extensions(filename) > 0) 
-        flat_sed = dfs_load_image(frameset, flat_sed_tag,  
-                                  CPL_TYPE_FLOAT, section, 1);
-    else 
-        flat_sed = dfs_load_image(frameset, flat_sed_tag, CPL_TYPE_FLOAT, 0, 1);
-
-    int nl = (lastLambda - firstLambda) / dispersion;
-    
-    cpl_image * mapped_flat_sed = 
-            cpl_image_new(nl, cpl_image_get_size_y(flat_sed), CPL_TYPE_FLOAT);
-    
-    for(size_t i_slit = 0; i_slit < det_slits.size(); ++i_slit)
-    {
-        int slit_begin_pos = 
-                det_slits[i_slit].get_position_spatial_corrected();
-        int slit_end_pos = slit_begin_pos +  
-                det_slits[i_slit].get_length_spatial_corrected();
-        int slit_pos_good_wavecal = vimos::flat_normaliser::get_middle_slit_valid_calib
-                (wave_cal, slit_end_pos, slit_begin_pos);
-        
-        for(cpl_size i_wave = 0; i_wave < nl; ++i_wave)
-        {
-            int null;
-            double wave = firstLambda + i_wave * dispersion;
-            double pixel = wave_cal.get_pixel(slit_pos_good_wavecal, wave);
-            int i_pix = std::ceil(pixel+0.5);
-            if(i_pix>= 0 && i_pix <cpl_image_get_size_x(flat_sed))
-                cpl_image_set(mapped_flat_sed, i_wave+1, i_slit+1, 
-                        cpl_image_get(flat_sed, i_pix+1, i_slit+1, &null));
-        }
-    }
-    cpl_image_delete(flat_sed);
-    return mapped_flat_sed;
-}
-
-void vimos_science_correct_flat_sed
+int vimos_science_correct_flat_sed
 (cpl_image *spectra,  cpl_table *objects,
  cpl_image * mapped_flat_sed,
  cpl_propertylist * flat_sed_header,
- cpl_propertylist * specphot_header)
+ cpl_propertylist * specphot_header,
+ const vimos::detected_slits& det_slits)
 {
 
     cpl_size nx = cpl_image_get_size_x(spectra);
@@ -394,7 +351,7 @@ void vimos_science_correct_flat_sed
          * So the original factor applied to the flat sed has to be removed 
          * and then aaply the one in the specphot */
         std::ostringstream norm_key;
-        norm_key<< "ESO QC FLAT SED"<<i_slit+1<<" NORM";
+        norm_key<< "ESO QC FLAT SED_"<<det_slits[i_slit].slit_id()<<" NORM";
         double flat_sed_norm_orig =
             cpl_propertylist_get_double(flat_sed_header, norm_key.str().c_str());
         double specphot_flat_sed_norm = 
@@ -427,16 +384,18 @@ void vimos_science_correct_flat_sed
         cpl_msg_warning(cpl_func, "The flat SED used to compute the response "
                 "includes in its normalisation factors the slit width. "
                 "However, the flat SED used to correct the science doesn't. "
-                "The flux calibration in this case will be off by a factor "
-                "equal to the ratio of the slit widths (science vs standard star)");
+                "The flux calibration in this case cannot be performed, "
+                "therefore stopping.");
 
+    return 0;
 }
 
-void vimos_science_correct_flat_sed_mapped
+int vimos_science_correct_flat_sed_mapped
 (cpl_image *mapped_image,  cpl_table *objects,
  cpl_image * mapped_flat_sed,
  cpl_propertylist * flat_sed_header,
- cpl_propertylist * specphot_header)
+ cpl_propertylist * specphot_header,
+ const vimos::detected_slits& det_slits)
 {
 
     cpl_size nx = cpl_image_get_size_x(mapped_image);
@@ -450,7 +409,7 @@ void vimos_science_correct_flat_sed_mapped
          * and then aaply the one in the specphot */
         int null;
         std::ostringstream norm_key;
-        norm_key<< "ESO QC FLAT SED"<<i_slit+1<<" NORM";
+        norm_key<< "ESO QC FLAT SED_"<<det_slits[i_slit].slit_id()<<" NORM";
         double flat_sed_norm_orig =
             cpl_propertylist_get_double(flat_sed_header, norm_key.str().c_str());
         double specphot_flat_sed_norm = 
@@ -480,8 +439,9 @@ void vimos_science_correct_flat_sed_mapped
         cpl_msg_warning(cpl_func, "The flat SED used to compute the response "
                 "includes in its normalisation factors the slit width. "
                 "However, the flat SED used to correct the science doesn't. "
-                "The flux calibration in this case will be off by a factor "
-                "equal to the ratio of the slit widths (science vs standard star)");
+                "The flux calibration in this case cannot be performed, "
+                "therefore stopping.");
 
+    return 0;
 }
 
