@@ -42,6 +42,7 @@
 #include "vmtypes.h"
 #include "vmfit.h"
 #include "vmdistmodels.h"
+#include "cpl.h"
 
 
 /* Constructors and destructors for the models */
@@ -59,19 +60,19 @@ VimosDistModel1D *newDistModel1D(const int order)
   }
   
   /* allocated space and check */
-  tmpMod = (VimosDistModel1D *) pil_malloc(sizeof(VimosDistModel1D));
+  tmpMod = (VimosDistModel1D *) cpl_malloc(sizeof(VimosDistModel1D));
   if (tmpMod == NULL) {
     cpl_msg_error(modName, "Allocation Error");
     return(NULL);
   }
   
   /* allocate array for coefficients  */
-  tmpMod->coefs = (double *) pil_calloc(order+1, sizeof(double));
+  tmpMod->coefs = (double *) cpl_calloc(order+1, sizeof(double));
 
   /* check allocation */
   if (tmpMod->coefs == NULL) {
     /* cleanup */
-    pil_free(tmpMod);
+    cpl_free(tmpMod);
     cpl_msg_error(modName, "Allocation Error");
     return(NULL);
   }
@@ -99,29 +100,29 @@ VimosDistModel2D *newDistModel2D(const int orderX, const int orderY)
   }
   
   /* allocated space and check */
-  tmpMod = (VimosDistModel2D *) pil_malloc(sizeof(VimosDistModel2D));
+  tmpMod = (VimosDistModel2D *) cpl_malloc(sizeof(VimosDistModel2D));
   if (tmpMod == NULL) {
     cpl_msg_error(modName, "Allocation Error");
     return(NULL);
   }
 
   /* allocate array for coefficients  */
-  tmpMod->coefs = (double **) pil_calloc(orderX+1, sizeof(double *));
+  tmpMod->coefs = (double **) cpl_calloc(orderX+1, sizeof(double *));
   
   /* check allocation */
   if (tmpMod->coefs == NULL) {
     /* cleanup */
-    pil_free(tmpMod);
+    cpl_free(tmpMod);
     cpl_msg_error(modName, "Allocation Error");
     return(NULL);
   }
   for (i=0; i <= orderX; i++) {
-    tmpMod->coefs[i] = (double *) pil_calloc(orderY+1, sizeof(double));
+    tmpMod->coefs[i] = (double *) cpl_calloc(orderY+1, sizeof(double));
 
     /* check allocation */
     if (tmpMod->coefs[i] == NULL) {
       /* cleanup */
-      pil_free(tmpMod);
+      cpl_free(tmpMod);
       cpl_msg_error(modName, "Allocation Error");
       return(NULL);
     }
@@ -156,7 +157,7 @@ VimosDistModelFull *newDistModelFull(const int orderPol,
   }
   
   /* allocated space and check */
-  tmpMod = (VimosDistModelFull *) pil_malloc(sizeof(VimosDistModelFull));
+  tmpMod = (VimosDistModelFull *) cpl_malloc(sizeof(VimosDistModelFull));
   if (tmpMod == NULL) {
     cpl_msg_error(modName, "Allocation Error");
     return(NULL);
@@ -164,10 +165,10 @@ VimosDistModelFull *newDistModelFull(const int orderPol,
 
   /* allocated space and check */
   tmpMod->coefs = 
-    (VimosDistModel2D **) pil_malloc((orderPol+1)*sizeof(VimosDistModel2D *));
+    (VimosDistModel2D **) cpl_malloc((orderPol+1)*sizeof(VimosDistModel2D *));
   if (tmpMod->coefs == NULL) {
     /* cleanup */
-    pil_free(tmpMod);
+    cpl_free(tmpMod);
     cpl_msg_error(modName, "Allocation Error");
     return(NULL);
   }
@@ -177,7 +178,7 @@ VimosDistModelFull *newDistModelFull(const int orderPol,
     tmpMod->coefs[i] = newDistModel2D(orderX, orderY);
     if (tmpMod->coefs[i] == NULL) {
       /* cleanup */
-      pil_free(tmpMod);
+      cpl_free(tmpMod);
       cpl_msg_error(modName, "The function newDistModel2D has returned NULL");
       return(NULL);
     }
@@ -201,9 +202,9 @@ void deleteDistModel1D(VimosDistModel1D *mod)
     return;
   }
   /* delete the array with coefficients */
-  pil_free(mod->coefs);
+  cpl_free(mod->coefs);
   /* delete sructure */
-  pil_free(mod);
+  cpl_free(mod);
   
 }
 
@@ -217,12 +218,12 @@ void deleteDistModel2D(VimosDistModel2D *mod)
   }
   /* delete coefficients */
   for (i=0; i <= mod->orderX; i++) {
-    pil_free(mod->coefs[i]);
+    cpl_free(mod->coefs[i]);
   }
-  pil_free(mod->coefs);
+  cpl_free(mod->coefs);
   
   /* delete structure */
-  pil_free(mod);
+  cpl_free(mod);
 }
 
 void deleteDistModelFull(VimosDistModelFull *mod)
@@ -238,7 +239,7 @@ void deleteDistModelFull(VimosDistModelFull *mod)
     deleteDistModel2D(mod->coefs[i]);
   }
   /* delete structure */
-  pil_free(mod);
+  cpl_free(mod);
 
 }
 
@@ -1002,7 +1003,7 @@ VimosGnomonic *newGnomonic(const double alpha0, const double delta0)
   VimosGnomonic *tmpGnome;
   
   /* allocate space */
-  tmpGnome = (VimosGnomonic *) pil_malloc(sizeof(VimosGnomonic));
+  tmpGnome = (VimosGnomonic *) cpl_malloc(sizeof(VimosGnomonic));
   if (tmpGnome == NULL) {
     cpl_msg_error(modName, "Allocation Error");
     return(NULL);
@@ -1023,7 +1024,7 @@ VimosGnomonic *newGnomonic(const double alpha0, const double delta0)
 void deleteGnomonic(VimosGnomonic *gnome)
 {
   if (gnome != NULL) {
-    pil_free(gnome);
+    cpl_free(gnome);
   }
 }
 
@@ -1136,7 +1137,7 @@ VimosBool fitDistModel2D(VimosPixel *surface, int numPoints, int polyDeg,
   }
   
   /* free temp array */
-  pil_free(tmpCoefs);
+  cpl_free(tmpCoefs);
 
   return(VM_TRUE);
 
